/**
 * Fight related functions for the Carnage Blender extension
 */

// Default bonus variant
const defaultBonusVariant = {
  challengeBonus: "0%",
  clanBonus: "0%",
  NUB: "0%",
  bonusTime: "-"
};

// Extract my minion's name from the "Post-battle stats" header.
const extractMyMinionNames = doc => {
  try {
    // Verwende serialisierten HTML-String
    const serializer = new XMLSerializer()
    const htmlString = serializer.serializeToString(doc)

    // Suche nach dem Text "Post-battle stats"
    const postBattleIndex = htmlString.indexOf("Post-battle stats")
    if (postBattleIndex === -1) {
      return ["NOMINIONNAMEFOUND"]
    }

    // Extrahiere die Zeile nach "Post-battle stats"
    const afterPostBattle = htmlString.substring(postBattleIndex + "Post-battle stats".length)
    const lineEnd = afterPostBattle.indexOf("Experience")

    if (lineEnd === -1) {
      return ["NOMINIONNAMEFOUND"]
    }

    // Die erste Zeile nach "Post-battle stats" sollte die Minion-Namen enthalten
    const namesLine = afterPostBattle.substring(0, lineEnd).trim()

    // Teile die Zeile nach Tabulatoren oder mehreren Leerzeichen
    const names = namesLine.split(/\t+|\s{2,}/).filter(name => name.trim() !== '')

    return names.length > 0 ? names : ["NOMINIONNAMEFOUND"]
  } catch (e) {
    return ["NOMINIONNAMEFOUND"]
  }
}

// Extract additional statistics from the fight log.
const extractAdditionalStats = textContent => {
  const doc = new DOMParser().parseFromString(textContent, 'text/html');
  const myMinionNames = extractMyMinionNames(doc);
  
  const stats = {
    enemyAmfDamage: 0,
    hpDrawn: 0,
    hpRegenerated: 0,
    weaponDamageDealt: 0,
    flameDamageDealt: 0,
    physDamageReceived: 0,
    magDamageReceived: 0,
    gaDamageReceived: 0,
    damageAbsorbed: 0,
    bleedDamageDealt: 0,
    magDamageDone: 0,    // Neue Stat für magischen Schaden
    amfBacklash: 0,      // Neue Stat für AMF-Backlash
    remainingHP: 0,      // Neue Stat für verbleibende Lebenspunkte
    robfDamageReceived: 0,  // Neue Stat für erhaltenen RoBF-Schaden
    // Objekte für Zähler pro Gegner
    enemyDebuffs: {
      clumsier: {}, // Format: { "Minion Name": Anzahl }
      weaker: {}    // Format: { "Minion Name": Anzahl }
    },
    minionDeaths: {}, // Format: { "Minion Name": Todesrunde }
  };

  // Extrahiere verbleibende Lebenspunkte aus den Post-Battle-Stats
  const postBattleStatsMatch = textContent.match(/Post-battle stats\n([^]*?)(?=\n\n|$)/);
  if (postBattleStatsMatch) {
    const postBattleStats = postBattleStatsMatch[1];
    const lines = postBattleStats.split('\n');
    
    // Finde die Zeile mit den Hit Points
    const hitPointsLine = lines.find(line => line.includes('Hit Points'));
    if (hitPointsLine) {
      // Extrahiere die Werte nach "Hit Points"
      const values = hitPointsLine.split(/\s+/).filter(v => v.match(/^-?[\d,]+$/));
      if (values.length >= 2) {
        // Summiere alle positiven Werte
        values.forEach(value => {
          const hp = parseInt(value.replace(/,/g, ''));
          if (hp > 0) {
            stats.remainingHP += hp;
          }
        });
      }
    }
  }

  const lines = textContent.split('\n');
  let currentRound = 1;

  for (let i = 0; i < lines.length; i++) {
    const line = lines[i];

    // Erkennen Sie Tode von Ihren Minions
    if (line.includes("R.I.P.")) {
      // Teile die Zeile bei Tabs oder mehreren Leerzeichen
      const ripParts = line.split(/\t+|\s{2,}/);
      
      // Gehe durch alle Teile
      for (const part of ripParts) {
        const ripMatch = part.match(/R\.I\.P\.\s+([^,]+)(?:,|$)/);
        if (ripMatch) {
          const deadMinionName = ripMatch[1].trim();
          // Prüfen Sie, ob es einer Ihrer Minions ist
          if (myMinionNames.includes(deadMinionName)) {
            const deathRound = determineRound(lines, i);
            stats.minionDeaths[deadMinionName] = deathRound;
          }
        }
      }
    }

    // Erstelle RegExp für jeden Minion-Namen
    for (const myName of myMinionNames) {
      const myNameRegex = myName.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');

      // --- My actions ---
      // HP drawn
      let m = line.match(new RegExp(myNameRegex + "\\s+draws strength from his weapon!\\s*\\[([\\d,\\.]+)\\]", "i"));
      if (m && m[1]) stats.hpDrawn += window.CBUtils.safeParse(m[1]);

      // HP regenerated
      m = line.match(new RegExp(myNameRegex + ".*regenerated\\s+([\\d,\\.]+)\\s*HP", "i"));
      if (m && m[1]) stats.hpRegenerated += window.CBUtils.safeParse(m[1]);

      // Damage absorbed - z.B. "a sandbag absorbs damage [4,239]"
      // a sandbag absorbs damage [54,072]
      m = line.match(new RegExp(myNameRegex + "\\s+absorbs damage\\s*\\[([\\d,\\.]+)\\]", "i"));
      if (m && m[1]) stats.damageAbsorbed += window.CBUtils.safeParse(m[1]);

      // Weapon damage dealt 
      if (line.includes(myName) && !/(draws strength|regenerated|burns from the flames|takes damage from his own|bleeds|absorbs|Guardian Angel)/i.test(line)) {
        m = line.match(new RegExp(myNameRegex + " .+? \\[([\\d,\\.]+)\\]", "i"));
        if (m && m[1]) stats.weaponDamageDealt += window.CBUtils.safeParse(m[1]);
      }

      // Guardian Angel smote
      m = line.match(new RegExp("Guardian Angel smote\\s+" + myNameRegex + ' \\(([\\d,\\.]+)\\)', "i"));
      if (m && m[1]) {
        stats.gaDamageReceived += window.CBUtils.safeParse(m[1]);
      }

      // Damage received 
      if (line.includes(myName) && !/(draws strength|regenerated|burns from the flames|takes damage from his own|bleeds|absorbs|Guardian Angel)/i.test(line)) {
        m = line.match(new RegExp(myNameRegex + " \\[([\\d,\\.]+)\\]", "i"));
        if (m && m[1]) {
          if (line.match(new RegExp("(Magic Missile|Decay|Fireball|Cone of Cold|Shocking Grasp)", "i"))) {
            stats.magDamageReceived += window.CBUtils.safeParse(m[1]);
          } else {
            stats.physDamageReceived += window.CBUtils.safeParse(m[1]);
          }
        }
      }
    }

    let isMyMinionLine = myMinionNames.some(name => line.includes(name));

    // --- Enemy actions ---
    // AMF damage: all lines with "takes damage from his own ..." not containing any of my minion names
    let m = line.match(/takes damage from his own .*\(([\d,\.]+)\)/i);
    if (m && m[1] && !isMyMinionLine) {
      stats.enemyAmfDamage += window.CBUtils.safeParse(m[1]);
    }

    // Magical damage done: lines containing magic spells hitting enemies
    // Prüfe ob einer unserer Minions am Anfang der Zeile steht
    const isMyMinionAttacking = myMinionNames.some(name => line.startsWith(name));
    m = line.match(/^([^!]+)(?:'s)?\s+(Magic Missile|Decay|Fireball|Cone of Cold|Shocking Grasp)\s+hit.*?\[([\d,\.]+)\]/i);
    if (m && m[1] && m[2] && isMyMinionAttacking) {
      stats.magDamageDone += window.CBUtils.safeParse(m[3]);
    }

    // AMF Backlash: lines containing "takes damage from his own" followed by a magic spell
    m = line.match(/^([^!]+)(?= takes damage from his own .*?\(([\d,\.]+)\))/i);
    if (m && m[1] && m[2] && isMyMinionAttacking) {
      stats.amfBacklash += window.CBUtils.safeParse(m[2]);
    }

    // RoBF damage (flame damage): all lines containing "burns from the flames surrounding"
    m = line.match(/^([^!]+)(?= burns from the flames surrounding\s+.*?\(([\d,\.]+)\))/i);
    if (m && m[1] && m[2]) {
      const burningMinion = m[1].trim();
      // Prüfe ob dies ein gegnerischer Minion ist (nicht unserer)
      const isMyMinion = myMinionNames.some(name => burningMinion === name);
      if (!isMyMinion) {
        stats.flameDamageDealt += window.CBUtils.safeParse(m[2]);
      } else {
        // Wenn es unser Minion ist, füge den Schaden zu robfDamageReceived hinzu
        stats.robfDamageReceived += window.CBUtils.safeParse(m[2]);
      }
    }

    // Bleed damage: all lines containing "bleeds from his deep wounds" but not from our minions
    m = line.match(/^([^!]+)(?= bleeds from his deep wounds\s*\(([\d,\.]+)\))/i);
    if (m && m[1] && m[2] && !isMyMinionLine) {
      const bleedingMinion = m[1].trim();
      stats.bleedDamageDealt += window.CBUtils.safeParse(m[2]);
    }
    
    // Zählt "looks clumsier" pro Minion
    if (line.includes("looks clumsier!")) {
      // Extrahiere den Minion-Namen, der "looks clumsier" wurde
      const minionMatch = line.match(/^([^!]+)(?= looks clumsier!)/);
      if (minionMatch && minionMatch[1]) {
        const minionName = minionMatch[1].trim();
        if (!stats.enemyDebuffs.clumsier[minionName]) {
          stats.enemyDebuffs.clumsier[minionName] = 1;
        } else {
          stats.enemyDebuffs.clumsier[minionName]++;
        }
      }
    }
    
    // Zählt "looks weaker" pro Minion
    if (line.includes("looks weaker!")) {
      // Extrahiere den Minion-Namen, der "looks weaker" wurde
      const minionMatch = line.match(/^([^!]+)(?= looks weaker!)/);
      if (minionMatch && minionMatch[1]) {
        const minionName = minionMatch[1].trim();
        // Aktualisiere den Zähler für diesen Minion
        if (!stats.enemyDebuffs.weaker[minionName]) {
          stats.enemyDebuffs.weaker[minionName] = 1;
        } else {
          stats.enemyDebuffs.weaker[minionName]++;
        }
      }
    }
  }
  return stats;
};

// Extract bonus data from the document
const extractBonusData = doc => {
  const bonusData = { ...defaultBonusVariant };
  const bonusTable = Array.from(doc.querySelectorAll("table.section-bg"))
    .find(table => table.innerText.includes("Bonuses"));
  if (bonusTable) {
    const rows = bonusTable.querySelectorAll("tr");
    rows.forEach(row => {
      if (row.classList.contains("header-font")) return;
      const cells = row.querySelectorAll("td");
      if (cells.length >= 2) {
        const link = cells[0].querySelector("a");
        if (link) {
          const text = link.textContent.trim();
          const lowerText = text.toLowerCase();
          const value = cells[1].textContent.trim();
          if (lowerText.includes("challenge bonus")) {
            bonusData.challengeBonus = value || "0%";
          } else if (lowerText.includes("clan bonus")) {
            bonusData.clanBonus = value || "0%";
          } else if (lowerText.includes("new user bonus") ||
                     lowerText.includes("nub") ||
                     lowerText.includes("ncb")) {
            bonusData.NUB = value || "0%";
          } else {
            bonusData.bonusTime = text || "-";
          }
        }
      }
    });
  }
  return bonusData;
};

// Extract fight results from the document
const extractFightResults = doc => {
  if (!doc || !doc.body || !doc.body.innerText) return;
  const textContent = doc.body.innerText;
  const resultMatch = textContent.match(/(\w+) defeated (.+?) (\(|after)/);
  const isWin = resultMatch !== null;
  if (!isWin) return;

  const opponentName = isWin ? resultMatch[2] : textContent.match(/(.+?) defeated (\w+)/)[1];
  if (!opponentName) return;

  // Extrahiere die Anzahl der Runden
  const roundsMatch = textContent.match(/after (\d+) rounds of combat/);
  const rounds = roundsMatch ? parseInt(roundsMatch[1]) : 0;

  const cashMatch = textContent.match(/Cash \(total\)\s*\$([0-9,]+)/);
  if (!cashMatch) return;

  const xpMatch = textContent.match(/XP \(per minion\)\s*([0-9,]+)/);
  if (!xpMatch) return;

  const cash = parseInt(cashMatch[1].replace(/,/g, ""), 10);
  const xp = parseInt(xpMatch[1].replace(/,/g, ""), 10);
  
  const bonusData = extractBonusData(doc);
  if (!bonusData) return;

  const bonusKey = `any|${bonusData.clanBonus}|${bonusData.NUB}|${bonusData.bonusTime}`;
  if (!bonusKey) return;

  // Prüfe ob dieser Kampf bereits gespeichert wurde
  chrome.storage.local.get({ lastFightsByOpponent: {} }, data => {
    const lastFightsByOpponent = data.lastFightsByOpponent;
    const lastFight = lastFightsByOpponent[opponentName]?.[bonusKey]?.fightData;

    if (lastFight && 
        lastFight.opponent === opponentName && 
        lastFight.cash === cash && 
        lastFight.xp === xp && 
        `any|${lastFight.bonusData.clanBonus}|${lastFight.bonusData.NUB}|${lastFight.bonusData.bonusTime}` === bonusKey) {
        return;
    }
    // Wenn es ein neuer Kampf ist, extrahiere zusätzliche Stats und speichere
    const additionalStats = extractAdditionalStats(textContent);
    const fightData = {
        opponent: opponentName,
        result: "Win",
        cash,
        xp,
        rounds,
        bonusData,
        additionalStats,
        timestamp: new Date().toISOString()
    };

    window.CBState.lastFightData = fightData;
    window.CBState.currentView = "lastFight";
    window.CBState.currentBonusKey = bonusKey;
    
    window.CBStorage.saveFightData(fightData);
  });
};

// Calculate detail stats from fight data
const calculateDetailStats = (fightData) => {
  const stats = {
    total: 1,
    wins: fightData[0].won ? 1 : 0,
    winRate: fightData[0].won ? 1 : 0,
    damageDealt: {
      total: fightData[0].additionalStats.weaponDamageDealt + 
             fightData[0].additionalStats.flameDamageDealt + 
             fightData[0].additionalStats.enemyAmfDamage +
             fightData[0].additionalStats.magDamageDone,
      avg: fightData[0].additionalStats.weaponDamageDealt + 
           fightData[0].additionalStats.flameDamageDealt + 
           fightData[0].additionalStats.enemyAmfDamage +
           fightData[0].additionalStats.magDamageDone
    },
    damageTaken: {
      total: fightData[0].additionalStats.physDamageReceived + 
             fightData[0].additionalStats.magDamageReceived + 
             fightData[0].additionalStats.gaDamageReceived +
             fightData[0].additionalStats.amfBacklash,
      avg: fightData[0].additionalStats.physDamageReceived + 
           fightData[0].additionalStats.magDamageReceived + 
           fightData[0].additionalStats.gaDamageReceived +
           fightData[0].additionalStats.amfBacklash
    },
    rounds: {
      total: fightData[0].rounds,
      avg: fightData[0].rounds
    }
  }

  return stats;
};

// Fügen Sie diese Funktion zur Rundenerkennung hinzu:
const determineRound = (lines, currentIndex) => {
  let round = 0;
  let currentPhase = "enchantments";
  let rangedRounds = 0;
  let meleeRounds = 0;
  
  // Finde zuerst die Kampfphasen-Marker
  let rangedStartIndex = -1;
  let meleeStartIndex = -1;
  
  // Finde die Phasen-Übergänge
  for (let i = 0; i <= currentIndex; i++) {
    const line = lines[i].trim();
    if (line === "Ranged Combat") {
      rangedStartIndex = i;
      currentPhase = "ranged";
    } else if (line === "Melee Combat") {
      meleeStartIndex = i;
      currentPhase = "melee";
    }
  }

  // Wenn wir noch in Enchantments sind
  if (currentPhase === "enchantments") {
    return 0;
  }

  // Zähle die Ranged-Runden (jede Gruppe von Aktionen zwischen zwei Leerzeilen)
  if (rangedStartIndex !== -1) {
    let emptyLineCount = 0;
    for (let i = rangedStartIndex; i < (meleeStartIndex !== -1 ? meleeStartIndex : currentIndex); i++) {
      if (lines[i].trim() === "") {
        emptyLineCount++;
      }
    }
    // Eine Runde wird durch zwei leere Zeilen begrenzt
    rangedRounds = Math.floor(emptyLineCount / 2);
    // Wenn die letzte Runde nicht mit einer leeren Zeile endet
    if (emptyLineCount % 2 !== 0) rangedRounds++;
  }

  // Wenn wir in Melee sind, zähle die Melee-Runden
  if (currentPhase === "melee") {
    let emptyLineCount = 0;
    for (let i = meleeStartIndex; i <= currentIndex; i++) {
      if (lines[i].trim() === "") {
        emptyLineCount++;
      }
    }
    // Eine Runde wird durch zwei leere Zeilen begrenzt
    meleeRounds = Math.floor(emptyLineCount / 2);
    // Wenn die letzte Runde nicht mit einer leeren Zeile endet
    if (emptyLineCount % 2 !== 0) meleeRounds++;
  }

  // Berechne die Gesamtrundenzahl
  if (currentPhase === "ranged") {
    return rangedRounds;
  } else if (currentPhase === "melee") {
    return rangedRounds + meleeRounds;
  }

  return 0; // Fallback
};

// Export fight functions
window.CBFight = {
  defaultBonusVariant,
  extractMyMinionNames,
  extractAdditionalStats,
  extractBonusData,
  extractFightResults,
  calculateDetailStats
};
