/**
 * Local Storage functions for the Carnage Blender extension (Firefox Version)
 */

// Save fight data to local storage
const saveFightData = fightData => {
  browser.storage.local.get({ aggStats: {}, lastFightsByOpponent: {} }).then(data => {
    const aggStats = data.aggStats;
    const lastFightsByOpponent = data.lastFightsByOpponent;
    const opponent = fightData.opponent;
    const timestamp = new Date().toISOString();
    
    // Speichere den Fight mit Zeitstempel
    if (!lastFightsByOpponent[opponent]) {
      lastFightsByOpponent[opponent] = {};
    }
    const bonus = fightData.bonusData;
    const bonusKey = `any|${bonus.clanBonus}|${bonus.NUB}|${bonus.bonusTime}`;
    
    lastFightsByOpponent[opponent][bonusKey] = {
      fightData: { ...fightData },
      date: new Date().toLocaleDateString(),
      time: new Date().toLocaleTimeString()
    };

    // Aggregierte Stats wie bisher...
    if (!aggStats[opponent]) aggStats[opponent] = {};
    if (!aggStats[opponent][bonusKey]) {
      aggStats[opponent][bonusKey] = {
        count: 0,
        totalXp: 0,
        totalXpSquare: 0,
        totalCash: 0,
        totalRounds: 0,
        bonusVariant: bonus,
        totalEnemyAmfDamage: 0,
        totalGaDamageReceived: 0,
        totalHpDrawn: 0,
        totalHpRegenerated: 0,
        totalWeaponDamageDealt: 0,
        totalFlameDamageDealt: 0,
        totalPhysDamageReceived: 0,
        totalMagDamageReceived: 0,
        totalDamageAbsorbed: 0,
        totalBleedDamageDealt: 0,
        totalMagDamageDone: 0,
        totalAmfBacklash: 0,
        totalRemainingHP: 0,
        totalEnemyDebuffs: {
          clumsier: {}, // Format: { "Minion Name": Anzahl }
          weaker: {}    // Format: { "Minion Name": Anzahl }
        },
        lastFightTime: timestamp,
        minXp: fightData.xp,    // Initialisiere min/max Werte
        maxXp: fightData.xp,
        minCash: fightData.cash,
        maxCash: fightData.cash,
        minRounds: fightData.rounds,
        maxRounds: fightData.rounds
      };
    } else {
      // Update min/max wenn der Eintrag bereits existiert
      const agg = aggStats[opponent][bonusKey];
      agg.minXp = Math.min(agg.minXp || fightData.xp, fightData.xp);
      agg.maxXp = Math.max(agg.maxXp || fightData.xp, fightData.xp);
      agg.minCash = Math.min(agg.minCash || fightData.cash, fightData.cash);
      agg.maxCash = Math.max(agg.maxCash || fightData.cash, fightData.cash);
      agg.minRounds = Math.min(agg.minRounds || fightData.rounds, fightData.rounds);
      agg.maxRounds = Math.max(agg.maxRounds || fightData.rounds, fightData.rounds);
    }
    // Prüfe ob mindestens ein Schadenswert größer als 0 ist
    const hasDamageData = fightData.additionalStats.enemyAmfDamage > 0 ||
                        fightData.additionalStats.gaDamageReceived > 0 ||
                        fightData.additionalStats.hpDrawn > 0 ||
                        fightData.additionalStats.hpRegenerated > 0 ||
                        fightData.additionalStats.weaponDamageDealt > 0 ||
                        fightData.additionalStats.flameDamageDealt > 0 ||
                        fightData.additionalStats.physDamageReceived > 0 ||
                        fightData.additionalStats.magDamageReceived > 0 ||
                        fightData.additionalStats.damageAbsorbed > 0 ||
                        fightData.additionalStats.bleedDamageDealt > 0 ||
                        fightData.additionalStats.magDamageDone > 0 ||
                        fightData.additionalStats.amfBacklash > 0 ||
                        fightData.additionalStats.remainingHP > 0;

    // Wenn keine Schadensdaten vorhanden sind, breche hier ab
    if (!hasDamageData) {
      return;
    }
    const agg = aggStats[opponent][bonusKey];
    agg.count += 1;
    agg.totalXp += fightData.xp;
    agg.totalXpSquare += fightData.xp * fightData.xp;
    agg.totalCash += fightData.cash;
    agg.totalRounds += fightData.rounds;
    agg.totalEnemyAmfDamage += fightData.additionalStats.enemyAmfDamage;
    agg.totalGaDamageReceived += fightData.additionalStats.gaDamageReceived;
    agg.totalHpDrawn += fightData.additionalStats.hpDrawn;
    agg.totalHpRegenerated += fightData.additionalStats.hpRegenerated;
    agg.totalWeaponDamageDealt += fightData.additionalStats.weaponDamageDealt;
    agg.totalFlameDamageDealt += fightData.additionalStats.flameDamageDealt;
    agg.totalPhysDamageReceived += fightData.additionalStats.physDamageReceived;
    agg.totalMagDamageReceived += fightData.additionalStats.magDamageReceived;
    agg.totalDamageAbsorbed += fightData.additionalStats.damageAbsorbed;
    agg.totalBleedDamageDealt += fightData.additionalStats.bleedDamageDealt;
    agg.totalMagDamageDone += fightData.additionalStats.magDamageDone;
    agg.totalAmfBacklash += fightData.additionalStats.amfBacklash;
    agg.totalRemainingHP += fightData.additionalStats.remainingHP;
    
    // Aktualisiere die aggregierten Debuff-Statistiken
    // Für "looks clumsier"
    if (fightData.additionalStats.enemyDebuffs && fightData.additionalStats.enemyDebuffs.clumsier) {
      Object.entries(fightData.additionalStats.enemyDebuffs.clumsier).forEach(([minionName, count]) => {
        if (!agg.totalEnemyDebuffs.clumsier[minionName]) {
          agg.totalEnemyDebuffs.clumsier[minionName] = count;
        } else {
          agg.totalEnemyDebuffs.clumsier[minionName] += count;
        }
      });
    }
    
    // Für "looks weaker"
    if (fightData.additionalStats.enemyDebuffs && fightData.additionalStats.enemyDebuffs.weaker) {
      Object.entries(fightData.additionalStats.enemyDebuffs.weaker).forEach(([minionName, count]) => {
        if (!agg.totalEnemyDebuffs.weaker[minionName]) {
          agg.totalEnemyDebuffs.weaker[minionName] = count;
        } else {
          agg.totalEnemyDebuffs.weaker[minionName] += count;
        }
      });
    }
    agg.lastFightTime = timestamp;
    
    // Update local storage
    browser.storage.local.set({ aggStats, lastFightsByOpponent }).then(() => {
      // Update global state
      window.CBState.currentBonusKey = bonusKey;
      window.CBState.currentView = "lastFight";
      window.CBState.lastFightData = fightData;
      
      // Update view
      window.CBView.updateView();
    });
  });
};

// Load items data from JSON file
const loadItemsData = async () => {
  try {
    const response = await fetch(browser.runtime.getURL('items.json'));
    const data = await response.json();
    // Verwende den items-Unterzweig der JSON
    window.CBState.loadedItems = data.items || {};
  } catch (e) {
    console.error("Error loading items data:", e);
    window.CBState.loadedItems = {};
  }
};

// Handle fight completion
const handleFightComplete = (fightData) => {
  // Speichere die Daten wie bisher
  saveFightData(fightData);
  
  // Setze die Ansicht auf lastFight statt global
  window.CBState.currentView = "lastFight";
  window.CBView.updateView();
};

// Export local storage functions
window.CBStorage = {
  saveFightData,
  loadItemsData,
  handleFightComplete
}; 