/**
 * Main entry point for the Carnage Blender extension
 * This file is responsible for loading all other modules and setting up the event listeners
 */

(() => {
  // Check if a frame has loaded and determine the view type
  const checkFrameLoaded = async () => {
    const cbmainFrame = window.parent.frames["cbmain"];
    if (!cbmainFrame || !cbmainFrame.document) return;

    const url = cbmainFrame.document.URL;
    if (!url) return;
    
    let newDetectedView = null;
    let contentChanged = false;
    
    if (url.includes("fight.tcl")) {
      newDetectedView = "global";
      window.CBFight.extractFightResults(cbmainFrame.document);
    } else if (url.includes("/train/")) {
      newDetectedView = "training";
      const trainingStats = window.CBTrain.extractTrainingStats(cbmainFrame.document);
      if (trainingStats) {
        const lastStats = localStorage.getItem('trainingStats');
        contentChanged = JSON.stringify(trainingStats) !== lastStats;
        if (contentChanged) {
          localStorage.setItem('trainingStats', JSON.stringify(trainingStats));
        }
      }
    } else if (url.includes("equip")) {
      newDetectedView = "equip";
      const stats = await window.CBEquip.extractAllArmorStats(cbmainFrame.document);
      if (stats) {
        contentChanged = JSON.stringify(stats) !== JSON.stringify(window.CBState.lastEquipStats);
        if (contentChanged) {
          window.CBState.lastEquipStats = stats;
          chrome.storage.local.set({ equipStats: stats });
        }
      }
    }

    // Aktualisiere die Ansicht nur wenn:
    // 1. sich die View geändert hat ODER
    // 2. wir in der aktuellen View sind UND sich der Inhalt geändert hat
    if (newDetectedView !== window.CBState.lastDetectedView) {  // Vereinfachte Bedingung
      window.CBState.lastDetectedView = newDetectedView;
      window.CBState.lastView = newDetectedView;
      window.CBState.currentView = newDetectedView;
      window.CBView.updateView();
    } else if (window.CBState.currentView === newDetectedView && contentChanged) {
      window.CBView.updateView();
    }
  };

  // Observe the fight frame for changes and set up initial sidebar styles
  const observeFightFrame = () => {
    const sidebarFrame = window.parent.frames["sidebar"];
    if (sidebarFrame) {
      const style = sidebarFrame.document.createElement("style");
      style.textContent =
        'div[style*="text-align: center"] h2 a[href="/directory/refer.tcl"] { display: none; } ' +
        'h2[style*="text-align: center"] a[href^="/shared/community-member.tcl"] { display: none; } ' +
        'hr { display:none; } ' +
        '#fightHistoryStats .opponent-row:hover { background-color: #ccc; } ';
      sidebarFrame.document.head.appendChild(style);
    }
    setInterval(checkFrameLoaded, 200);
  };

  // Initialize the extension
  const init = async () => {
    // Load settings first
    window.CBStorage.loadSettings();
    await window.CBStorage.loadItemsData();    
    window.addEventListener("load", observeFightFrame);
    
    // Update fight history stats
    setTimeout(window.CBView.updateFightHistoryStats, 500);
    setTimeout(checkFrameLoaded, 1000);
    setTimeout(checkFrameLoaded, 2000);
    
  };

  // Start the extension
  init();
})();