/**
 * Training related functions for the Carnage Blender extension
 */

// Extract training stats from the document
const extractTrainingStats = doc => {
  const allStats = {};
  
  // Finde alle Minion-Divs
  const minionDivs = doc.querySelectorAll('div[id^="minion"]');
  
  minionDivs.forEach(minionDiv => {
    const minionId = minionDiv.id.replace('minion', '');
    const nameElement = doc.querySelector(`#name${minionId}`);
    
    // Prüfe ob das Namenselement existiert
    if (!nameElement) {
      return false;
    }
    
    const minionName = nameElement.textContent.trim();
    const stats = {};
    
    // Finde die Stats-Tabelle für diesen Minion
    const statsTable = minionDiv.querySelector('#statstable');
    if (!statsTable) {
      return false;
    }

    const rows = statsTable.querySelectorAll('tr');
    rows.forEach(row => {
      const cells = row.querySelectorAll('td');
      if (cells.length >= 3) {
        const nameCell = cells[0].querySelector('b');
        if (!nameCell) return;
        
        const statName = nameCell.textContent.trim().replace(':', ''); // Entferne Doppelpunkte
        const currentValue = window.CBUtils.safeParse(cells[1].textContent);
        // Spezialbehandlung für Hit Points
        if (statName === 'Hit Points') {
          stats[statName] = {
            base: currentValue,
            modified: currentValue,
            percentChange: "0.0"
          };
          return;
        }
        
        // Extrahiere raw value, mit Fallback auf currentValue
        let rawValue = currentValue;
        if (cells[2]) {
          const rawSpan = cells[2].querySelector('span');
          if (rawSpan) {
            rawValue = window.CBUtils.safeParse(rawSpan.textContent);
          } else {
            rawValue = window.CBUtils.safeParse(cells[2].textContent);
          }
        }
        
        if (currentValue > 0) {
          const percentChange = rawValue > 0 ? 
            ((currentValue / rawValue - 1) * 100).toFixed(1) : 
            "0.0";
            
          stats[statName] = {
            base: rawValue,
            modified: currentValue,
            percentChange: percentChange
          };
        }
      }
    });
    
    if (Object.keys(stats).length > 0) {
      allStats[minionName] = stats;
    }
  });

  if (Object.keys(allStats).length > 0) {
    localStorage.setItem('trainingStats', JSON.stringify(allStats));
    window.CBState.currentView = "training";
  }
  else{
    return false
  }
  
  return allStats;
};

// Export training functions
window.CBTrain = {
  extractTrainingStats
};