/**
 * View related functions for the Carnage Blender extension
 */
// Update settings view
const updateSettingsView = () => {
  const sidebarFrame = window.CBUtils.getSidebarFrame();
  if (!sidebarFrame) return;

  let settingsHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
    <legend>Settings 
      (<a href="#" id="showGlobal">&laquo;</a>)
    </legend>
    <div style="font-size:10px;">
      <div style="margin-bottom:10px;">
        <label for="windowHeight">Fensterhöhe:</label>
        <input type="number" id="windowHeight" value="${window.CBState.windowHeight}" min="100" max="500" style="width:60px;">
        <button id="saveWindowHeight">Speichern</button>
      </div>
    </div>
  </fieldset>`;

  let statsContainer = sidebarFrame.document.getElementById("fightHistoryStats");
  if (statsContainer) {
    statsContainer.innerHTML = settingsHtml;
    
    const globalLink = sidebarFrame.document.getElementById("showGlobal");
    
    if (globalLink) {
      globalLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "global";
        updateView();
      });
    }
    
    // Event-Listener für den Speichern-Button
    const saveButton = sidebarFrame.document.getElementById("saveWindowHeight");
    if (saveButton) {
      saveButton.addEventListener("click", () => {
        const heightInput = sidebarFrame.document.getElementById("windowHeight");
        if (heightInput) {
          const newHeight = parseInt(heightInput.value);
          if (!isNaN(newHeight) && newHeight >= 100 && newHeight <= 500) {
            window.CBStorage.saveSettings({ windowHeight: newHeight });
          }
        }
      });
    }
  }
};

// Render enemy debuffs by minion
const renderEnemyDebuffs = (enemyDebuffs) => {
  if (!enemyDebuffs) return '';
  
  let html = '';
  
  // Section für "looks clumsier" falls vorhanden
  if (Object.keys(enemyDebuffs.clumsier || {}).length > 0) {
    Object.entries(enemyDebuffs.clumsier).forEach(([minionName, count]) => {
      html += `<div class="debuff-dealt">clumsier ${minionName}: <span style="float:right;">${count.toFixed(0)}x</span></div>`;
    });
  }
  
  // Section für "looks weaker" falls vorhanden
  if (Object.keys(enemyDebuffs.weaker || {}).length > 0) {
    Object.entries(enemyDebuffs.weaker).forEach(([minionName, count]) => {
      html += `<div class="debuff-dealt">weaker ${minionName}: <span style="float:right;">${count.toLocaleString()}x</span></div>`;
    });
  }
  
  return html;
};

// Render total enemy debuffs with average per fight
const renderTotalEnemyDebuffs = (totalEnemyDebuffs, fightCount) => {
  if (!totalEnemyDebuffs || fightCount <= 0) return '';
  
  let html = '';
  
  // Section für "looks clumsier" falls vorhanden
  if (Object.keys(totalEnemyDebuffs.clumsier || {}).length > 0) {
    Object.entries(totalEnemyDebuffs.clumsier).forEach(([minionName, totalCount]) => {
      const avgCount = (totalCount / fightCount).toFixed(1);
      html += `<div class="debuff-dealt">Ø clumsier ${minionName}: <span style="float:right;">${avgCount}x</span></div>`;
    });
  }
  
  // Section für "looks weaker" falls vorhanden
  if (Object.keys(totalEnemyDebuffs.weaker || {}).length > 0) {
    Object.entries(totalEnemyDebuffs.weaker).forEach(([minionName, totalCount]) => {
      const avgCount = (totalCount / fightCount).toFixed(1);
      html += `<div class="debuff-dealt">Ø weaker ${minionName}: <span style="float:right;">${avgCount}x</span></div>`;
    });
  }
  
  return html;
};

// Definiere die verfügbaren Statistiken global
const availableStats = [
  { key: 'xp', label: 'XP' },
  { key: 'weaponDamage', label: 'Weapon Damage Dealt' },
  { key: 'gaDamageReceived', label: 'GA Received' },
  { key: 'magDamage', label: 'Magic Damage Dealt' },
  { key: 'amfBacklash', label: 'AMF Backlash Received' },
  { key: 'amfDamage', label: 'AMF Damage Dealt' },
  { key: 'flameDamage', label: 'RoBF Damage Dealt' },
  { key: 'robfDamageReceived', label: 'RoBF Damage Received' },
  { key: 'bleedDamage', label: 'Bleed Damage Dealt' },
  { key: 'damageAbsorbed', label: 'Damage Absorbed' },
  { key: 'physDamageReceived', label: 'Physical Damage Received' },
  { key: 'magDamageReceived', label: 'DD Received' },
  { key: 'hpDrawn', label: 'HP Drawn' },
  { key: 'hpRegenerated', label: 'HP Regenerated' },
  { key: 'remainingHP', label: 'Remaining HP' },
  { key: 'rounds', label: 'Rounds' },
  { key: 'minionDeaths', label: 'Minion Deaths' }
];

// Update view based on current state
const updateView = () => {
  // Stelle sicher, dass CBState initialisiert ist
  if (!window.CBState) {
    initializeExtension();
    return;
  }

  if (window.CBState.currentView === "training") {
    const trainingStatsStr = localStorage.getItem('trainingStats');
    if (trainingStatsStr) {
      try {
        const trainingStats = JSON.parse(trainingStatsStr);
        updateTrainingStatsDisplay(trainingStats);
      } catch (e) {
        console.error('Fehler beim Parsen der Trainingsdaten:', e);
      }
    }
  } else if (window.CBState.currentView === "equip") {
    chrome.storage.local.get(['equipStats'], data => {
      if (data.equipStats) {
        updateEquipStatsDisplay(data.equipStats);
      }
    });
  } else if (window.CBState.currentView === "global") {
    // Initialisiere currentBonusKey wenn noch nicht gesetzt
    if (!window.CBState.currentBonusKey && window.CBState.lastFightData) {
      const bonus = window.CBState.lastFightData.bonusData;
      let bonus_time_str = bonus.bonusTime;
      if (bonus_time_str.includes("XP")) bonus_time_str = "XP";
      if (bonus_time_str.includes("money")) bonus_time_str = "$$";
      window.CBState.currentBonusKey = `any|${bonus.clanBonus}|${bonus.NUB}|${bonus_time_str}`;
    }
    updateFightHistoryStats();
  } else if (window.CBState.currentView === "detail" && window.CBState.lastFightData) {
    updateDetailView(window.CBState.lastFightData.opponent);
  } else if (window.CBState.currentView === "lastFight" && window.CBState.lastFightData) {
    updateLastFightView(window.CBState.lastFightData);
  } else if (window.CBState.currentView === "settings") {
    updateSettingsView();
  }
};

// Update training stats display
const updateTrainingStatsDisplay = stats => {
  let statsHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
      <legend>Train 
          (<a href="#" id="showGlobal">&laquo;</a>)
      </legend>
      <div style="font-size:10px;">`;

  let steel_skin = 0;
  // Für jeden Minion
  for (const [minionName, minionStats] of Object.entries(stats)) {
    statsHtml += `<div style="margin-bottom:5px;"><b>${minionName}:</b>`;
    
    // Zeige erst die einzelnen Stats mit Prozentänderung
    for (const [stat, data] of Object.entries(minionStats)) {
      const changeSymbol = parseFloat(data.percentChange) > 0 ? '+' : '';
      statsHtml += `<div style="padding-left:0px;">${stat}: <span style="float:right;">${changeSymbol}${data.percentChange}%</span></div>`;
    }

    // Berechne Summen für diesen Minion
    let sumLvl = 0;
    let sumRaw = 0;
    for (const data of Object.values(minionStats)) {
      sumLvl += data.modified;
      sumRaw += data.base;
    }

    // Füge Tabelle für diesen Minion hinzu
    statsHtml += `<table style="width:100%; margin-top:10px; margin-bottom:10px; border-collapse:collapse;">
      <tr style="border-bottom:1px solid #ccc;">
        <th style="text-align:left;">% of Total</th>
        <th style="text-align:right;">Lvl</th>
        <th style="text-align:right;">Raw</th>
      </tr>`;

    // Berechne Prozente für jeden Stat dieses Minions
    let hp = 0;
    for (const [stat, data] of Object.entries(minionStats)) {
      const lvlPercent = ((data.modified / sumLvl) * 100).toLocaleString('de-DE', {minimumFractionDigits: 1, maximumFractionDigits: 1});
      const rawPercent = ((data.base / sumRaw) * 100).toLocaleString('de-DE', {minimumFractionDigits: 1, maximumFractionDigits: 1});
      if( stat === 'Hit Points')
      {
        hp = data.base;
      }

      if( stat === 'Steel Skin')
      {
        steel_skin = data.modified;
      }
      statsHtml += `<tr>
        <td>${stat}</td>
        <td style="text-align:right;">${lvlPercent}%</td>
        <td style="text-align:right;">${rawPercent}%</td>
      </tr>`;

    }

    if( steel_skin > 0)
    {
        let percent_of_hp = (steel_skin / hp) * 100
        let color = '#006000';
        if( percent_of_hp < 12.5)
        {
          color = '#880000';
        }
      let additional = '';
        additional = ` `;

      statsHtml += `<tr>
        <td>Steel Skin % of HP:</td>
        <td style="text-align:right;"><span style="color:${color};">${percent_of_hp.toLocaleString('de-DE', {minimumFractionDigits: 1, maximumFractionDigits: 1})}%</span></td>
        <td style="text-align:right;"></td>
      </tr>`;
    }

    statsHtml += `<tr style="border-top:1px solid #ccc;">
      <td>Total</td>
      <td style="text-align:right;">${sumLvl.toLocaleString('de-DE')}</td>
      <td style="text-align:right;">${sumRaw.toLocaleString('de-DE')}</td>
    </tr>
    </table>`;

    statsHtml += '</div>';
  }

  statsHtml += `</div></fieldset>`;

  let statsContainer = window.CBUtils.getSidebarFrame().document.getElementById("fightHistoryStats");
  if (statsContainer) {
    statsContainer.innerHTML = statsHtml;
    
    const globalLink = window.CBUtils.getSidebarFrame().document.getElementById("showGlobal");
    
    if (globalLink) {
      globalLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "global";
        updateView();
      });
    }
  }
};

// Update equip stats display
const updateEquipStatsDisplay = stats => {
  const sidebarFrame = window.CBUtils.getSidebarFrame();
  if (!sidebarFrame) return;

  let statsHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
    <legend>Equip 
      (<a href="#" id="showGlobal">&laquo;</a>)
    </legend>
    <div style="font-size:10px;">`;

  for (const [minionName, minionStats] of Object.entries(stats)) {
    if (!minionStats || !minionStats.equippedItems) {
      continue;
    }

    // Initialisiere die Zusammenfassungen für diesen Minion
    minionStats.totalBaseAC = 0;
    minionStats.totalEnchantedAC = 0;
    minionStats.totalAC = 0;
    
    // Sammle alle Stat-Modifikatoren
    const totalStatModifiers = {};
    
    // Berechne die Summen für diesen Minion
    minionStats.equippedItems.forEach(item => {
      const baseAC = item.jsonMatch?.effects?.base_ac || 0;
      const enchantedAC = (item.jsonMatch?.effects?.enchanted_ac === true) ? item.enchantment : 0;
      minionStats.totalBaseAC += baseAC;
      minionStats.totalEnchantedAC += enchantedAC;

      // Sammle Stat-Modifikatoren von jedem Item
      if (item.calculatedEffects.statModifiers) {
        Object.entries(item.calculatedEffects.statModifiers).forEach(([stat, value]) => {
          if (!totalStatModifiers[stat]) {
            totalStatModifiers[stat] = 0;
          }
          totalStatModifiers[stat] += value;
        });
      }
    });

    // Berechne die Gesamtsumme für diesen Minion
    minionStats.totalAC = minionStats.totalBaseAC + minionStats.totalEnchantedAC;

    statsHtml += `<div style="margin-bottom:8px;">
      <b>${minionName}:</b>
      <div style="padding-left:10px;margin-bottom:8px;border-bottom:1px solid #ccc;">
        <div style="display:flex;justify-content:space-between;">
          <span>Base AC:</span>
          <span>${minionStats.totalBaseAC}</span>
        </div>
        <div style="display:flex;justify-content:space-between;">
          <span>Enchanted AC:</span>
          <span>${minionStats.totalEnchantedAC}</span>
        </div>
        <div style="display:flex;justify-content:space-between;">
          <span>Total AC:</span>
          <span>${minionStats.totalAC}</span>
        </div>`;
    // Berechne Damage Reduction
    const physicalDR = Math.round((minionStats.totalAC) * 0.167);
    const magicalDR = Math.round(minionStats.totalEnchantedAC * 0.167);

    const physicalDR_mit_steel_skin = Math.round((minionStats.totalAC) * 0.21);
    const magicalDR_mit_steel_skin = Math.round(minionStats.totalEnchantedAC * 0.21);
    
    statsHtml += `<div style="display:flex;justify-content:space-between;">
      <span>Physical reduction:</span>
      <span>${physicalDR}% / ${physicalDR_mit_steel_skin}% (SS)</span>
    </div>
    <div style="display:flex;justify-content:space-between;">
      <span>Magical reduction:</span>
      <span>${magicalDR}% / ${magicalDR_mit_steel_skin}% (SS)</span>
    </div>`;
    // Zeige die summierten Stat-Modifikatoren
    Object.entries(totalStatModifiers).forEach(([stat, value]) => {
      const displayStat = window.CBUtils.statAbbrev[stat] || stat;
      if (displayStat === 'AC') {
        return;
      }
      statsHtml += `<div style="display:flex;justify-content:space-between;">
        <span>${displayStat}:</span>
        <span>${value >= 0 ? '+' : ''}${(value * 100).toFixed(1)}${displayStat == 'Enemy Hit Penalty' ? '' : '%'}</span>
      </div>`;
      
    });
    /*
    // Zeige die summierten staticen Effekte
    const totalStaticEffects = {};
    minionStats.equippedItems.forEach(item => {
      if (item.jsonMatch?.effects?.static_effects) {
        Object.entries(item.jsonMatch.effects.static_effects).forEach(([stat, value]) => {
          if (!totalStaticEffects[stat]) {
            totalStaticEffects[stat] = 0;
          }
          totalStaticEffects[stat] += value;
        });
      }
    });
    // Zeige die Summen der staticen Effekte an
    Object.entries(totalStaticEffects).forEach(([stat, value]) => {
      const displayStat = window.CBUtils.statAbbrev[stat] || stat;
      if (displayStat === 'AC') {
        return;
      }
      statsHtml += `<div style="display:flex;justify-content:space-between;">
        <span>${displayStat} (static):</span>
        <span>${value >= 0 ? '+' : ''}${(value * 100).toFixed(1)}%</span>
      </div>`;
    });
    */
    /*
    // Zeige den DX Shield Penalty an, falls vorhanden
    if (minionStats.calculatedEffects?.statModifiers?.dx_shield_penalty) {
      const penalty = minionStats.calculatedEffects.statModifiers.dx_shield_penalty;
      statsHtml += `<div style="display:flex;justify-content:space-between;">
        <span>DX Shield Penalty:</span>
        <span>${(penalty * 100).toFixed(1)}%</span>
      </div>`;
    }
    */
    statsHtml += `</div>`;

    /*
    minionStats.equippedItems.forEach(item => {
      const baseAC = item.jsonMatch?.effects?.base_ac || 0;
      const enchantedAC = (item.jsonMatch?.effects?.enchanted_ac === true) ? item.enchantment : 0;
      const itemTotalAC = baseAC + enchantedAC;

      statsHtml += `<div style="padding-left:10px;margin-bottom:4px;">
        <div>${item.displayName}</div>`;
      
      if (item.calculatedEffects.statModifiers) {
        Object.entries(item.calculatedEffects.statModifiers).forEach(([stat, value]) => {
          const displayStat = window.CBUtils.statAbbrev[stat] || stat;
          if (displayStat === 'AC') {
            return;
          }
          statsHtml += `<div style="padding-left:20px;">${displayStat}: ${value >= 0 ? '+' : ''}${(value * 100).toFixed(1)}%</div>`;
        });
      }
      // Zeige statice Effekte an, wenn vorhanden
      if (item.jsonMatch?.effects?.static_effects) {
        Object.entries(item.jsonMatch.effects.static_effects).forEach(([stat, value]) => {
          const displayStat = window.CBUtils.statAbbrev[stat] || stat;
          if (displayStat === 'AC') {
            return;
          }
          statsHtml += `<div style="padding-left:20px;">${displayStat}: ${value >= 0 ? '+' : ''}${(value * 100).toFixed(1)}%</div>`;
        });
      }
      statsHtml += `</div>`;
    });
    */

    statsHtml += `</div>`;
  }

  statsHtml += `</div></fieldset>`;

  let statsContainer = sidebarFrame.document.getElementById("fightHistoryStats");
  if (statsContainer) {
    statsContainer.innerHTML = statsHtml;
    
    const globalLink = sidebarFrame.document.getElementById("showGlobal");
    const trainingLink = sidebarFrame.document.getElementById("showTraining");
    
    if (globalLink) {
      globalLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "global";
        updateView();
      });
    }
    
    if (trainingLink) {
      trainingLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "training";
        updateView();
      });
    }
  }
};

// Update last fight view
const updateLastFightView = (fightData) => {
  let statsHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
      <legend>${fightData.opponent} 
          (<a href="#" id="showGlobal">&laquo;</a>)
      </legend>`;

  const bonus = fightData.bonusData;
  let bonus_time_str = '';
  if (bonus.bonusTime) {
    bonus_time_str = bonus.bonusTime;
    if (bonus_time_str.includes("XP")) bonus_time_str = "XP";
    if (bonus_time_str.includes("money")) bonus_time_str = "$$";
  }
  // Setze currentBonusKey basierend auf dem aktuellen Kampf-Bonus
  window.CBState.currentBonusKey = `any|${bonus.clanBonus}|${bonus.NUB}|${bonus.bonusTime}`;
  statsHtml += `<div style="font-size:10px;order-bottom:1px solid #ccc; padding:2px 0;">
    <div class="bonuskey">${bonus.clanBonus} | ${bonus.NUB} | ${bonus_time_str}</div>
    <div>Challenge Bonus: <span style="float:right;font-weight:normal;">${parseInt(bonus.challengeBonus).toLocaleString()}%</span></div>
    <div class="stat-link" data-stat="xp">XP: <span style="float:right;font-weight:bold;">${parseInt(fightData.xp).toLocaleString()}</span></div>
    <div>CB$: <span style="float:right;">$${parseInt(fightData.cash).toLocaleString()}</span></div>
    ${fightData.rounds > 0 ? `<div class="stat-link" data-stat="rounds">Rounds: <span style="float:right;">${parseInt(fightData.rounds).toLocaleString()}</span></div>` : ''}
    ${Object.entries(fightData.additionalStats.minionDeaths).map(([minionName, round]) => 
      `<div class="death-info"><b>†</b> ${minionName}<span style="float:right;">${round}</span></div>`
    ).join('')}
    ${fightData.additionalStats.remainingHP > 0 ? `<div class="stat-link hp-drawn" data-stat="remainingHP">Remaining HP: <span style="float:right;">${parseInt(fightData.additionalStats.remainingHP).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.hpDrawn > 0 ? `<div class="stat-link hp-drawn" data-stat="hpDrawn">HP Drawn: <span style="float:right;">${parseInt(fightData.additionalStats.hpDrawn).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.hpRegenerated > 0 ? `<div class="stat-link hp-drawn" data-stat="hpRegenerated">HP Regenerated: <span style="float:right;">${parseInt(fightData.additionalStats.hpRegenerated).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.weaponDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="weaponDamage">Weapon Damage Dealt: <span style="float:right;">${parseInt(fightData.additionalStats.weaponDamageDealt).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.magDamageDone > 0 ? `<div class="stat-link damage-dealt" data-stat="magDamage">Magic Damage Dealt: <span style="float:right;">${parseInt(fightData.additionalStats.magDamageDone).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.enemyAmfDamage > 0 ? `<div class="stat-link damage-dealt" data-stat="amfDamage">AMF Damage Dealt: <span style="float:right;">${parseInt(fightData.additionalStats.enemyAmfDamage).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.flameDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="flameDamage">RoBF Damage Dealt: <span style="float:right;">${parseInt(fightData.additionalStats.flameDamageDealt).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.bleedDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="bleedDamage">Bleed Damage Dealt: <span style="float:right;">${parseInt(fightData.additionalStats.bleedDamageDealt).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.damageAbsorbed > 0 ? `<div class="stat-link absorb-dealt" data-stat="damageAbsorbed">Damage Absorbed: <span style="float:right;">${parseInt(fightData.additionalStats.damageAbsorbed).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.physDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="physDamageReceived">Physical Damage Received: <span style="float:right;">${parseInt(fightData.additionalStats.physDamageReceived).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.magDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="magDamageReceived">DD Received: <span style="float:right;">${parseInt(fightData.additionalStats.magDamageReceived).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.gaDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="gaDamageReceived">GA Received: <span style="float:right;">${parseInt(fightData.additionalStats.gaDamageReceived).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.amfBacklash > 0 ? `<div class="stat-link damage-received" data-stat="amfBacklash">AMF Backlash Received: <span style="float:right;">${parseInt(fightData.additionalStats.amfBacklash).toLocaleString()}</span></div>` : ''}
    ${fightData.additionalStats.robfDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="robfDamageReceived">RoBF Damage Received: <span style="float:right;">${parseInt(fightData.additionalStats.robfDamageReceived).toLocaleString()}</span></div>` : ''}
    ${renderEnemyDebuffs(fightData.additionalStats.enemyDebuffs)}
    
    <style>
      .stat-link {
        cursor: pointer;
      }
      .stat-link:hover {
        text-decoration: underline;
      }
      .hp-drawn {
        color: #006000;
      }
      .damage-dealt {
        color: #000080;
      }
      .damage-received {
        color: #950000;
      }
      .absorb-dealt {
        color: #660066;
      }
      .debuff-dealt {
        color: #333;
      }
      .death-info {
        color: #000;
        font-style: italic;
      }
    </style>
    </div>`;

  statsHtml += `</div></fieldset>`;
  const sidebarFrame = window.CBUtils.getSidebarFrame();
  if (sidebarFrame) {
    let statsContainer = sidebarFrame.document.getElementById("fightHistoryStats");
    if (!statsContainer) {
      statsContainer = sidebarFrame.document.createElement("div");
      statsContainer.id = "fightHistoryStats";
      sidebarFrame.document.body.appendChild(statsContainer);
    }
    statsContainer.innerHTML = statsHtml;

    const globalLink = sidebarFrame.document.getElementById("showGlobal");
    const trainingLink = sidebarFrame.document.getElementById("showTraining");
    
    if (globalLink) {
      globalLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "global";
        updateView();
      });
    }
    
    if (trainingLink) {
      trainingLink.addEventListener("click", e => {
        e.preventDefault();
        window.CBState.currentView = "training";
        updateView();
      });
    }

    // Fügen Sie nach dem Setzen des HTML den Event-Listener für die Statistik-Links hinzu:
    const statLinks = sidebarFrame.document.querySelectorAll('.stat-link');
    statLinks.forEach(link => {
      link.addEventListener('click', e => {
        const statKey = link.getAttribute('data-stat');
        if (statKey === 'minionDeaths') {
          const minionName = link.getAttribute('data-minion');
          window.CBState.currentMinionFilter = minionName;  // Speichere den ausgewählten Minion
        }
        // Finde den Index der Statistik in availableStats
        const statIndex = availableStats.findIndex(stat => stat.key === statKey);
        if (statIndex !== -1) {
          window.CBState.currentStatIndex = statIndex;
          window.CBState.currentView = "global";
          updateFightHistoryStats();
        }
      });
    });
  }
};

// Update detail view for a specific opponent
const updateDetailView = opponent => {
  chrome.storage.local.get({ aggStats: {}, lastFightsByOpponent: {} }, data => {
    const aggStats = data.aggStats;
    const lastFights = data.lastFightsByOpponent;
    const opponentData = aggStats[opponent];
    if (!opponentData) return;

    // Sammle alle verfügbaren Gegner
    const availableOpponents = Object.keys(aggStats).sort();
    const currentOpponentIndex = availableOpponents.indexOf(opponent);
    const nextOpponentIndex = (currentOpponentIndex + 1) % availableOpponents.length;
    const nextOpponent = availableOpponents[nextOpponentIndex];

    // Verfügbare Bonus-Keys für diesen Gegner sammeln
    const availableBonusKeysForOpponent = Object.keys(opponentData);
    
    // Wenn kein aktueller Bonus-Key gesetzt oder nicht verfügbar, nehme den ersten
    if (!window.CBState.currentBonusKey || !availableBonusKeysForOpponent.includes(window.CBState.currentBonusKey)) {
      if (availableBonusKeysForOpponent.length > 0) {
        window.CBState.currentBonusKey = availableBonusKeysForOpponent[0];
      } else {
        // Fallback auf Default-Werte wenn keine Bonus-Keys verfügbar sind
        window.CBState.currentBonusKey = "any|0%|0%|-";
      }
    }

    const stats = opponentData[window.CBState.currentBonusKey];
    const bonus = stats.bonusVariant;
    
    let detailHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
      <legend><a href="#" id="nextOpponentLink">${opponent.substr(0,20)}</a> (<a href="#" id="backLink">&laquo;</a>)</legend>
      <div style="font-size:10px;">`;

    let bonus_time_str = '';
    if (bonus.bonusTime) {
      bonus_time_str = bonus.bonusTime;
      if (bonus_time_str.includes("XP")) bonus_time_str = "XP";
      if (bonus_time_str.includes("money")) bonus_time_str = "$$";
    }

    const avgXp = (stats.totalXp / stats.count).toFixed(0);
    const avgEnemyAmf = (stats.totalEnemyAmfDamage / stats.count).toFixed(0);
    const avgGaDamageReceived = (stats.totalGaDamageReceived / stats.count).toFixed(0);
    const avgHpDrawn = (stats.totalHpDrawn / stats.count).toFixed(0);
    const avgHpRegenerated = (stats.totalHpRegenerated / stats.count).toFixed(0);
    const avgWeaponDamageDealt = (stats.totalWeaponDamageDealt / stats.count).toFixed(0);
    const avgFlameDamageDealt = (stats.totalFlameDamageDealt / stats.count).toFixed(0);
    const avgPhysDamageReceived = (stats.totalPhysDamageReceived / stats.count).toFixed(0);
    const avgMagDamageReceived = (stats.totalMagDamageReceived / stats.count).toFixed(0);
    const avgDamageAbsorbed = (stats.totalDamageAbsorbed / stats.count).toFixed(0);
    const avgBleedDamageDealt = (stats.totalBleedDamageDealt / stats.count).toFixed(0);
    const avgMagDamageDone = (stats.totalMagDamageDone / stats.count).toFixed(0);
    const avgAmfBacklash = (stats.totalAmfBacklash / stats.count).toFixed(0);
    const avgRemainingHP = (stats.totalRemainingHP / stats.count).toFixed(0);
    const avgRobfDamageReceived = (stats.totalRobfDamageReceived / stats.count).toFixed(0);

    const variance = (stats.totalXpSquare / stats.count) - (avgXp * avgXp);
    const stdDev = Math.sqrt(Math.abs(variance));
    const marginOfError = 1.96 * (stdDev / Math.sqrt(stats.count));
    const confidenceLower = (parseFloat(avgXp) - marginOfError).toFixed(0);
    const confidenceUpper = (parseFloat(avgXp) + marginOfError).toFixed(0);
    let stdDevPercentage = 0;
    if (stdDev > 0) 
    {
      stdDevPercentage = (Math.round((10 * marginOfError / avgXp) * 100)/10).toFixed(1) || 0;
    }

    detailHtml += `<div style="border-bottom:1px solid #ccc; padding:2px 0;">
      <div class="bonuskey"><a href="#" id="cycleBonusDetail">${stats.count} x ${bonus.clanBonus} | ${bonus.NUB} | ${bonus_time_str} &raquo;</a></div>
      <div>Challenge Bonus: <span style="float:right;font-weight:normal;">${parseInt(bonus.challengeBonus).toLocaleString()}%</span></div>
      <div class="stat-link" data-stat="xp">Ø XP: <span style="float:right;">${parseInt(avgXp).toLocaleString()}</span></div>
      <div>Ø CB$: <span style="float:right;">$${parseInt(stats.totalCash / stats.count).toLocaleString()}</span></div>
      ${stats.totalRounds > 0 ? `<div class="stat-link" data-stat="rounds">Ø Rounds: <span style="float:right;">${(stats.totalRounds / stats.count).toFixed(1).toLocaleString()}</span></div>` : ''}
      ${Object.entries(stats.totalMinionDeaths || {}).map(([minionName, deathData]) => {
        const avgRound = (deathData.rounds.reduce((a, b) => a + b, 0) / deathData.count).toFixed(1);
        const deathRate = ((deathData.count / stats.count) * 100).toFixed(1);
        return `<div class="death-info stat-link" data-stat="minionDeaths" data-minion="${minionName}">Ø <b>†</b> ${minionName}: <span style="float:right;">${avgRound}/${deathRate}%</span></div>`;
      }).join('')}
      ${avgRemainingHP > 0 ? `<div class="stat-link hp-drawn" data-stat="remainingHP">Ø Remaining HP: <span style="float:right;">${parseInt(avgRemainingHP).toLocaleString()}</span></div>` : ''}
      ${avgHpDrawn > 0 ? `<div class="stat-link hp-drawn" data-stat="hpDrawn">Ø HP Drawn: <span style="float:right;">${parseInt(avgHpDrawn).toLocaleString()}</span></div>` : ''}
      ${avgHpRegenerated > 0 ? `<div class="stat-link hp-drawn" data-stat="hpRegenerated">Ø HP Regenerated: <span style="float:right;">${parseInt(avgHpRegenerated).toLocaleString()}</span></div>` : ''}
      ${avgWeaponDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="weaponDamage">Ø Weapon Damage Dealt: <span style="float:right;">${parseInt(avgWeaponDamageDealt).toLocaleString()}</span></div>` : ''}
      ${avgMagDamageDone > 0 ? `<div class="stat-link damage-dealt" data-stat="magDamage">Ø Magic Damage Dealt: <span style="float:right;">${parseInt(avgMagDamageDone).toLocaleString()}</span></div>` : ''}
      ${avgEnemyAmf > 0 ? `<div class="stat-link damage-dealt" data-stat="amfDamage">Ø AMF Damage Dealt: <span style="float:right;">${parseInt(avgEnemyAmf).toLocaleString()}</span></div>` : ''}
      ${avgFlameDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="flameDamage">Ø RoBF Damage Dealt: <span style="float:right;">${parseInt(avgFlameDamageDealt).toLocaleString()}</span></div>` : ''}
      ${avgBleedDamageDealt > 0 ? `<div class="stat-link damage-dealt" data-stat="bleedDamage">Ø Bleed Damage Dealt: <span style="float:right;">${parseInt(avgBleedDamageDealt).toLocaleString()}</span></div>` : ''}
      ${avgDamageAbsorbed > 0 ? `<div class="stat-link absorb-dealt" data-stat="damageAbsorbed">Ø Damage Absorbed: <span style="float:right;">${parseInt(avgDamageAbsorbed).toLocaleString()}</span></div>` : ''}
      ${avgPhysDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="physDamageReceived">Ø Physical Damage Received: <span style="float:right;">${parseInt(avgPhysDamageReceived).toLocaleString()}</span></div>` : ''}
      ${avgMagDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="magDamageReceived">Ø DD Received: <span style="float:right;">${parseInt(avgMagDamageReceived).toLocaleString()}</span></div>` : ''}
      ${avgGaDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="gaDamageReceived">Ø GA Received: <span style="float:right;">${parseInt(avgGaDamageReceived).toLocaleString()}</span></div>` : ''}
      ${avgAmfBacklash > 0 ? `<div class="stat-link damage-received" data-stat="amfBacklash">Ø AMF Backlash Received: <span style="float:right;">${parseInt(avgAmfBacklash).toLocaleString()}</span></div>` : ''}
      ${avgRobfDamageReceived > 0 ? `<div class="stat-link damage-received" data-stat="robfDamageReceived">Ø RoBF Damage Received: <span style="float:right;">${parseInt(avgRobfDamageReceived).toLocaleString()}</span></div>` : ''}
      ${renderTotalEnemyDebuffs(stats.totalEnemyDebuffs, stats.count)}
      <div style="color:#666;">XP standard deviation: <span style="float:right;">${stdDev.toFixed(0)}</span></div>
      <div style="color:#666;">XP confidence interval: <span style="float:right;">${confidenceLower} - ${confidenceUpper}</span></div>
      <div style="color:#666;">XP confidence % deviation: <span style="float:right;">±${stdDevPercentage}%</span></div>
      <div style="color:#666;">XP min/max: <span style="float:right;">${stats.minXp?.toLocaleString()} - ${stats.maxXp?.toLocaleString()}</span></div>
      <div style="color:#666;">CB$ min/max: <span style="float:right;">$${stats.minCash?.toLocaleString()} - $${stats.maxCash?.toLocaleString()}</span></div>

      <style>
        .stat-link {
          cursor: pointer;
        }
        .stat-link:hover {
          text-decoration: underline;
        }
        .hp-drawn {
          color: #006000;
        }
        .damage-dealt {
          color: #000080;
        }
        .damage-received {
          color: #950000;
        }
        
        .absorb-dealt {
          color: #660066;
        }

        .debuff-dealt {
          color: #333;
        }
        
        #cycleBonusDetail {
          text-decoration: none;
        }
      </style>`;

    // Füge den letzten Kampf für diesen Bonus-Key hinzu, falls vorhanden
    if (lastFights[opponent] && lastFights[opponent][window.CBState.currentBonusKey]) {
      const lastFight = lastFights[opponent][window.CBState.currentBonusKey].fightData;
      
      detailHtml += `<div style="border-top:1px solid #ccc; margin-top:5px; padding-top:5px;">
        <div style="font-weight:bold;">last fight ${lastFights[opponent][window.CBState.currentBonusKey].date} ${lastFights[opponent][window.CBState.currentBonusKey].time}:</div>
        <div>XP: <span style="float:right;">${lastFight.xp.toLocaleString()}</span></div>
        <div>CB$: <span style="float:right;">$${lastFight.cash.toLocaleString()}</span></div>
        ${lastFight.rounds > 0 ? `<div>Rounds: <span style="float:right;">${lastFight.rounds.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats ? Object.entries(lastFight.additionalStats.minionDeaths).map(([minionName, round]) => 
          `<div class="death-info"><b>†</b> ${minionName}<span style="float:right;">${round}</span></div>`
        ).join('') : ''}

        ${lastFight.additionalStats.remainingHP > 0 ? `<div class="hp-drawn">Remaining HP: <span style="float:right;">${lastFight.additionalStats.remainingHP.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.hpDrawn > 0 ? `<div class="hp-drawn">HP Drawn: <span style="float:right;">${lastFight.additionalStats.hpDrawn.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.hpRegenerated > 0 ? `<div class="hp-drawn">HP Regenerated: <span style="float:right;">${lastFight.additionalStats.hpRegenerated.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.weaponDamageDealt > 0 ? `<div class="damage-dealt">Weapon Damage: <span style="float:right;">${lastFight.additionalStats.weaponDamageDealt.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.magDamageDone > 0 ? `<div class="damage-dealt">Magic Damage: <span style="float:right;">${lastFight.additionalStats.magDamageDone.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.enemyAmfDamage > 0 ? `<div class="damage-dealt">AMF Damage: <span style="float:right;">${lastFight.additionalStats.enemyAmfDamage.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.flameDamageDealt > 0 ? `<div class="damage-dealt">RoBF Damage: <span style="float:right;">${lastFight.additionalStats.flameDamageDealt.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.bleedDamageDealt > 0 ? `<div class="damage-dealt">Bleed Damage: <span style="float:right;">${lastFight.additionalStats.bleedDamageDealt.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.damageAbsorbed > 0 ? `<div class="absorb-dealt">Damage Absorbed: <span style="float:right;">${lastFight.additionalStats.damageAbsorbed.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.physDamageReceived > 0 ? `<div class="damage-received">Physical Received: <span style="float:right;">${lastFight.additionalStats.physDamageReceived.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.magDamageReceived > 0 ? `<div class="damage-received">DD Received: <span style="float:right;">${lastFight.additionalStats.magDamageReceived.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.gaDamageReceived > 0 ? `<div class="damage-received">GA Received: <span style="float:right;">${lastFight.additionalStats.gaDamageReceived.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.amfBacklash > 0 ? `<div class="damage-received">AMF Backlash Received: <span style="float:right;">${lastFight.additionalStats.amfBacklash.toLocaleString()}</span></div>` : ''}
        ${lastFight.additionalStats.robfDamageReceived > 0 ? `<div class="damage-received">RoBF Damage Received: <span style="float:right;">${lastFight.additionalStats.robfDamageReceived.toLocaleString()}</span></div>` : ''}
        ${renderEnemyDebuffs(lastFight.additionalStats.enemyDebuffs)}
      </div>`;
    }
    
    detailHtml += `</div>`;
    detailHtml += `</div><br/><br/></fieldset>`;
    const sidebarFrame = window.CBUtils.getSidebarFrame();
    if (sidebarFrame) {
      let statsContainer = sidebarFrame.document.getElementById("fightHistoryStats");
      if (statsContainer) {
        statsContainer.innerHTML = detailHtml;
        
        const backLink = sidebarFrame.document.getElementById("backLink");
        const cycleDetailLink = sidebarFrame.document.getElementById("cycleBonusDetail");
        const nextOpponentLink = sidebarFrame.document.getElementById("nextOpponentLink");
        
        if (backLink) {
          backLink.addEventListener("click", e => {
            e.preventDefault();
            window.CBState.currentView = "global";
            updateFightHistoryStats();
          });
        }

        if (cycleDetailLink) {
          cycleDetailLink.addEventListener("click", e => {
            e.preventDefault();
            const currentIndex = availableBonusKeysForOpponent.indexOf(window.CBState.currentBonusKey);
            const nextIndex = (currentIndex + 1) % availableBonusKeysForOpponent.length;
            window.CBState.currentBonusKey = availableBonusKeysForOpponent[nextIndex];
            updateDetailView(opponent);
          });
        }

        if (nextOpponentLink) {
          nextOpponentLink.addEventListener("click", e => {
            e.preventDefault();
            updateDetailView(nextOpponent);
          });
        }

        const statLinks = sidebarFrame.document.querySelectorAll('.stat-link');
        statLinks.forEach(link => {
          link.addEventListener('click', e => {
            const statKey = link.getAttribute('data-stat');
            if (statKey === 'minionDeaths') {
              const minionName = link.getAttribute('data-minion');
              window.CBState.currentMinionFilter = minionName;  // Speichere den ausgewählten Minion
            }
            // Finde den Index der Statistik in availableStats
            const statIndex = availableStats.findIndex(stat => stat.key === statKey);
            if (statIndex !== -1) {
              window.CBState.currentStatIndex = statIndex;
              window.CBState.currentView = "global";
              updateFightHistoryStats();
            }
          });
        });
      }
    }
  });
};

// Update fight history stats
const updateFightHistoryStats = () => {
  // Initialisiere CBState falls noch nicht vorhanden
  if (!window.CBState) {
    window.CBState = {
      currentView: "global",
      currentStatIndex: 0,
      currentBonusKey: null,
      currentMinionFilter: null,
      lastFightData: null
    };
  }

  chrome.storage.local.get({ aggStats: {}, lastFightsByOpponent: {} }, data => {
    const aggStats = data.aggStats;
    const lastFights = data.lastFightsByOpponent;

    // Initialisiere currentStatIndex wenn noch nicht gesetzt
    if (typeof window.CBState.currentStatIndex === 'undefined') {
      window.CBState.currentStatIndex = 0;
    }

    // Wenn wir minionDeaths anzeigen aber noch kein Filter gesetzt ist,
    // initialisiere den Filter mit dem ersten verfügbaren Minion
    if (availableStats[window.CBState.currentStatIndex].key === 'minionDeaths' && !window.CBState.currentMinionFilter) {
      // Durchsuche alle Gegner nach dem ersten verfügbaren Minion
      for (const opponentVariants of Object.values(aggStats)) {
        for (const stats of Object.values(opponentVariants)) {
          if (stats.totalMinionDeaths) {
            const firstMinion = Object.keys(stats.totalMinionDeaths)[0];
            if (firstMinion) {
              window.CBState.currentMinionFilter = firstMinion;
              break;
            }
          }
        }
        if (window.CBState.currentMinionFilter) break;
      }
    }

    // Sammle alle verfügbaren Bonus-Kombinationen
    const availableBonusKeys = Array.from(new Set(
      Object.values(aggStats).flatMap(opponentVariants => 
        Object.keys(opponentVariants)
      )
    ));
    
    // Setze currentBonusKey wenn noch nicht gesetzt oder wenn der aktuelle Key keine Kämpfe hat
    if (!window.CBState.currentBonusKey || window.CBState.currentBonusKey === "any|0%|0%|-" || 
        !Object.values(aggStats).some(opponentVariants => opponentVariants[window.CBState.currentBonusKey])) {
      
      // Finde den neuesten Bonus-Key mit tatsächlichen Kämpfen
      let newestDate = null;
      let newestBonusKey = null;
      let newestFightCount = 0;

      // Durchsuche alle Gegner und ihre Bonus-Keys
      Object.entries(aggStats).forEach(([opponent, opponentVariants]) => {
        Object.entries(opponentVariants).forEach(([bonusKey, stats]) => {
          // Prüfe ob dieser Bonus-Key Kämpfe hat
          if (stats.count > 0) {
            const lastFight = lastFights[opponent]?.[bonusKey];
            if (lastFight) {
              const fightDate = new Date(lastFight.date + ' ' + lastFight.time);
              if (!newestDate || fightDate > newestDate) {
                newestDate = fightDate;
                newestBonusKey = bonusKey;
                newestFightCount = stats.count;
              }
            }
          }
        });
      });

      if (newestBonusKey) {
        window.CBState.currentBonusKey = newestBonusKey;
      } else if (window.CBState.lastFightData) {
        // Fallback auf den Bonus-Key des letzten Kampfes
        const bonus = window.CBState.lastFightData.bonusData;
        let bonus_time_str = bonus.bonusTime;
        if (bonus_time_str.includes("XP")) bonus_time_str = "XP";
        if (bonus_time_str.includes("money")) bonus_time_str = "$$";
        window.CBState.currentBonusKey = `any|${bonus.clanBonus}|${bonus.NUB}|${bonus_time_str}`;
      } else if (availableBonusKeys.length > 0) {
        // Finde den Bonus-Key mit den meisten Kämpfen
        let maxFights = 0;
        let bestKey = availableBonusKeys[0];
        availableBonusKeys.forEach(bonusKey => {
          let totalFights = 0;
          Object.values(aggStats).forEach(opponentVariants => {
            if (opponentVariants[bonusKey]) {
              totalFights += opponentVariants[bonusKey].count;
            }
          });
          if (totalFights > maxFights) {
            maxFights = totalFights;
            bestKey = bonusKey;
          }
        });
        window.CBState.currentBonusKey = bestKey;
      } else {
        // Absoluter Fallback auf Default-Werte
        window.CBState.currentBonusKey = "any|0%|0%|-";
      }
    }
    
    // Parse den aktuellen Bonus-Key
    const parts = window.CBState.currentBonusKey.split("|");
    const currentBonusVariant = {
      challengeBonus: parts[0],
      clanBonus: parts[1],
      NUB: parts[2],
      bonusTime: parts[3]
    };

    let bonus_time_str = '';
    if (currentBonusVariant.bonusTime) {
      bonus_time_str = currentBonusVariant.bonusTime;
      if (bonus_time_str.includes("XP")) bonus_time_str = "XP";
      if (bonus_time_str.includes("money")) bonus_time_str = "$$";
    }

    let fightHistoryHtml = `<fieldset style="height:${window.CBState.windowHeight}px; overflow:auto;">
      <legend>Ø (
       <a href="#" id="showEquip" style="font-weight:normal;">equip</a> |
       <a href="#" id="showTraining" style="font-weight:normal;">train</a>
       ${window.CBState.lastFightData ? ` 
       | <a href="#" id="showLastFight" style="font-weight:normal;">last</a>` : ''})</legend>`;

    fightHistoryHtml += `
    <div style="font-size:10px;"><a href="#" class="bonuskey" id="cycleBonus">Bonus: ${currentBonusVariant.clanBonus} | ${currentBonusVariant.NUB} | ${bonus_time_str} &raquo;</a>
    <br>
    <a href="#" id="cycleStatBackwards">&laquo;</a>
    <b><a href="#" id="cycleStat">Ø ${availableStats[window.CBState.currentStatIndex].key === 'minionDeaths' 
      ? `† ${window.CBState.currentMinionFilter}` 
      : availableStats[window.CBState.currentStatIndex].label} &raquo;</a></b>
    <br>
    `;

    let opponentsList = Object.keys(aggStats).map(opponent => {
      const variants = aggStats[opponent];
      if (variants[window.CBState.currentBonusKey]) {
        const stats = variants[window.CBState.currentBonusKey];
        let value = 0;
        let xpValue = stats.totalXp / stats.count; // Speichere XP-Wert für Sortierung
        
        // Berechne den Wert basierend auf dem aktuellen Stat
        switch(availableStats[window.CBState.currentStatIndex].key) {
          case 'xp':
            value = xpValue;
            break;
          case 'weaponDamage':
            value = stats.totalWeaponDamageDealt / stats.count;
            break;
          case 'magDamage':
            value = stats.totalMagDamageDone / stats.count;
            break;
          case 'amfDamage':
            value = stats.totalEnemyAmfDamage / stats.count;
            break;
          case 'flameDamage':
            value = stats.totalFlameDamageDealt / stats.count;
            break;
          case 'bleedDamage':
            value = stats.totalBleedDamageDealt / stats.count;
            break;
          case 'damageAbsorbed':
            value = stats.totalDamageAbsorbed / stats.count;
            break;
          case 'physDamageReceived':
            value = stats.totalPhysDamageReceived / stats.count;
            break;
          case 'magDamageReceived':
            value = stats.totalMagDamageReceived / stats.count;
            break;
          case 'gaDamageReceived':
            value = stats.totalGaDamageReceived / stats.count;
            break;
          case 'amfBacklash':
            value = stats.totalAmfBacklash / stats.count;
            break;
          case 'hpDrawn':
            value = stats.totalHpDrawn / stats.count;
            break;
          case 'hpRegenerated':
            value = stats.totalHpRegenerated / stats.count;
            break;
          case 'remainingHP':
            value = stats.totalRemainingHP / stats.count;
            break;
          case 'rounds':
            value = stats.totalRounds / stats.count;
            break;
          case 'robfDamageReceived':
            value = stats.totalRobfDamageReceived / stats.count;
            break;
          case 'minionDeaths':
            if (window.CBState.currentMinionFilter) {
              const minionDeaths = stats.totalMinionDeaths?.[window.CBState.currentMinionFilter];
              if (minionDeaths) {
                const avgRound = (minionDeaths.rounds.reduce((a, b) => a + b, 0) / minionDeaths.count).toFixed(1);
                const deathRate = ((minionDeaths.count / stats.count) * 100).toFixed(1);
                value = { avgRound, deathRate };  // Speichere beide Werte
              } else {
                value = { avgRound: 0, deathRate: 0 };
              }
            }
            break;
        }
        
        // Berechne Konfidenzintervall nur für XP
        const variance = (stats.totalXpSquare / stats.count) - Math.pow(stats.totalXp / stats.count, 2);
        let confidenceLower = 0;
        let confidenceUpper = 0;
        if (variance >= 0) {
          const stdDev = Math.sqrt(variance);
          const marginOfError = 1.96 * (stdDev / Math.sqrt(stats.count));
          confidenceLower = value - marginOfError;
          confidenceUpper = value + marginOfError;
        }
        
        return { opponent, stats, value, xpValue, confidenceLower, confidenceUpper };
      }
      return null;
    }).filter(item => item !== null);
    
    // Sortiere basierend auf XP statt auf dem aktuellen Wert
    opponentsList.sort((a, b) => a.xpValue - b.xpValue);

    // Prüfe Überschneidungen der Konfidenzintervalle
    opponentsList.forEach((item, index) => {
      item.hasOverlap = true;
      // Vergleiche mit allen anderen Gegnern
      opponentsList.forEach((other, otherIndex) => {
        if (index !== otherIndex) {
          // Keine Überschneidung wenn:
          if (item.confidenceUpper < other.confidenceLower || 
              item.confidenceLower > other.confidenceUpper) {
            item.hasOverlap = false;
          }
        }
      });
    });

    opponentsList.forEach(item => {
      const { opponent, stats, value, hasOverlap } = item;
      let valueFormatted;
      
      if (availableStats[window.CBState.currentStatIndex].key === 'minionDeaths') {
        if( value.avgRound > 0)
        {
          valueFormatted = `${value.avgRound}/${value.deathRate}%`;
        }
        else
        {
          valueFormatted = ''
        }
      } else if (availableStats[window.CBState.currentStatIndex].key === 'rounds') {
        valueFormatted = value.toFixed(1);
      } else {
        valueFormatted = parseInt(value.toFixed(0)).toLocaleString();
      }

      // Bestimme Farbe basierend auf Überschneidung und Position
      let color = '';
      if( availableStats[window.CBState.currentStatIndex].key === 'xp')
      {
        if (!hasOverlap) {
          const isLowest = item === opponentsList[0];
          const isHighest = item === opponentsList[opponentsList.length - 1];
          if (isLowest) color = '#950000';
          if (isHighest) color = '#000095';
        }
      }
      // Prüfe auf gültige Werte für die Standardabweichung
      let stdDevPercentage = 0;
      let stdDev = 0;
      if (stats.totalXpSquare && stats.totalXp) {
        const variance = (stats.totalXpSquare / stats.count) - Math.pow(stats.totalXp / stats.count, 2);
        if (variance >= 0) {
          stdDev = Math.sqrt(variance);
          const marginOfError = 1.96 * (stdDev / Math.sqrt(stats.count));
          stdDevPercentage = (Math.round((10 * marginOfError / value) * 100)/10).toFixed(1) || 0;
        }
      }

      if (window.CBState.lastFightData && opponent === window.CBState.lastFightData.opponent) {
        fightHistoryHtml += '<div style="color:#950000;">';
      }

      fightHistoryHtml += `<div class="opponent-row" data-opponent="${opponent}" style="cursor:pointer;${color ? `color:${color};` : ''}">
        <span class="count-col">${stats.count}</span>
        <span class="name-col">${opponent}</span>
        <span class="bonus-col">${stats.bonusVariant.challengeBonus || '0%'}</span>
        <span class="value-col">${valueFormatted} ${availableStats[window.CBState.currentStatIndex].key === 'xp' ? ` <span class="dev-col">±${stdDevPercentage}%</span>` : ''}</span>
      </div>`;

      if (window.CBState.lastFightData && opponent === window.CBState.lastFightData.opponent) {
        fightHistoryHtml += '</div>';
      }
    });

    // Berechne Gesamtdurchschnitt für XP
    if (availableStats[window.CBState.currentStatIndex].key === 'xp') {
      let totalXP = 0;
      let totalFights = 0;
      opponentsList.forEach(item => {
        totalXP += item.stats.totalXp;
        totalFights += item.stats.count;
      });
      
      const avgTotalXP = totalFights > 0 ? totalXP / totalFights : 0;
      
      fightHistoryHtml += `
        <div style="margin-top:10px; padding-top:5px; border-top:1px solid #ccc;">
          <div class="opponent-row">
            <span class="count-col">${totalFights}</span>
            <span class="name-col">Total average XP</span>
            <span class="bonus-col"></span>
            <span class="value-col">${parseInt(avgTotalXP).toLocaleString()}</span>
          </div>
        </div>`;
    }

    fightHistoryHtml += `<br><br><a href="#" id="clearDB">clear stats</a> | <a href="#" id="export">export</a> | <a href="#" id="settings">settings</a>`;
    fightHistoryHtml += `</div></fieldset>`;

    // Füge CSS-Styles für das Grid hinzu
    fightHistoryHtml += `
    <style>
      .opponent-row {
        display: grid;
        grid-template-columns: 25px minmax(70px, 1fr) 25px 72px;
        gap: 1px;
        align-items: center;
      }
      .opponent-row:hover {
        background-color: rgba(0,0,0,0.05);
      }
      .count-col {
        text-align: left;
      }
      .name-col {
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
      }
      .bonus-col {
        color: #666;
        font-size: 8px;
        text-align: right;
      }
      .value-col {
        text-align: right;
      }
      .dev-col {
        color: #666;
        font-size: 8px;
        display:inline-block;
        width:30px;
      }
    </style>
    `;

    const sidebarFrame = window.CBUtils.getSidebarFrame();
    if (sidebarFrame) {
      let statsContainer = sidebarFrame.document.getElementById("fightHistoryStats");
      if (!statsContainer) {
        statsContainer = sidebarFrame.document.createElement("div");
        statsContainer.id = "fightHistoryStats";
        const tryAppendContainer = () => {
          const opponentsDiv = sidebarFrame.document.getElementById("quicklinks");
          if (opponentsDiv) {
            opponentsDiv.parentNode.insertBefore(statsContainer, opponentsDiv.nextSibling);
            return true;
          }
          return false;
        };

        const waitForOpponents = () => {
          if (!tryAppendContainer()) {
            setTimeout(waitForOpponents, 1000);
          }
        };

        waitForOpponents();
      }
      
      statsContainer.innerHTML = fightHistoryHtml;
      addFightHistoryEventListeners(sidebarFrame);
    }
  });
};

// Add event listeners to the fight history buttons
const addFightHistoryEventListeners = (sidebarFrame) => {
  const clearLink = sidebarFrame.document.getElementById("clearDB");
  const trainingLink = sidebarFrame.document.getElementById("showTraining");
  const equipLink = sidebarFrame.document.getElementById("showEquip");
  const lastFightLink = sidebarFrame.document.getElementById("showLastFight");
  const cycleLink = sidebarFrame.document.getElementById("cycleBonus");
  const exportLink = sidebarFrame.document.getElementById("export");
  const settingsLink = sidebarFrame.document.getElementById("settings");

  if (clearLink) {
    clearLink.addEventListener("click", e => {
      e.preventDefault();
      if (!confirm("Are you sure you want to clear the fight stats?")) return;
      chrome.storage.local.set({ aggStats: {} }, () => {
        window.CBState.lastFightData = null;
        updateFightHistoryStats();
      });
    });
  }

  if (exportLink) {
    exportLink.addEventListener("click", e => {
      e.preventDefault();
      // Lade alle benötigten Daten
      chrome.storage.local.get({ 
        aggStats: {}, 
        lastFightsByOpponent: {} 
      }, data => {
        const aggStats = data.aggStats;
        const lastFights = data.lastFightsByOpponent;
        const bonusKey = window.CBState.currentBonusKey;

        // Lade Training Stats aus localStorage
        const trainingStatsStr = localStorage.getItem('trainingStats');
        let trainingStats = {};
        if (trainingStatsStr) {
          try {
            trainingStats = JSON.parse(trainingStatsStr);
          } catch (e) {
            console.error('Fehler beim Parsen der Trainingsdaten:', e);
          }
        }

        // Lade Equipment Stats aus chrome.storage
        chrome.storage.local.get(['equipStats'], equipData => {
          const equipStats = equipData.equipStats || {};
          
          // Sammle alle verfügbaren Trainings-Statistiken
          let trainingHeaders = [];
          if (trainingStats) {
            // Sammle alle Stat-Namen aus den Training Stats
            Object.values(trainingStats).forEach(minionStats => {
              Object.keys(minionStats).forEach(stat => {
                if (!trainingHeaders.includes(stat)) {
                  trainingHeaders.push(stat);
                }
              });
            });
          }
          
          // Sammle alle verfügbaren Equip-Statistiken
          let equipHeaders = [];
          if (equipStats) {
            // Sammle alle Stat-Modifikatoren
            Object.values(equipStats).forEach(minionStats => {
              if (minionStats.equippedItems) {
                minionStats.equippedItems.forEach(item => {
                  if (item.calculatedEffects?.statModifiers) {
                    Object.keys(item.calculatedEffects.statModifiers).forEach(stat => {
                      if (!equipHeaders.includes(stat)) {
                        equipHeaders.push(stat);
                      }
                    });
                  }
                });
              }
            });
          }
          
          console.log("Training Stats:", trainingHeaders);
          console.log("Equip Stats:", equipHeaders);
          
          // CSV Header erstellen
          let csvContent = "Opponent,Count,Challenge Bonus,Clan Bonus,NUB,Bonus Time," +
            "Avg XP,Avg CB$,Avg Rounds,Avg Remaining HP,Avg HP Drawn,Avg HP Regenerated," +
            "Avg Weapon Damage Dealt,Avg Magic Damage Dealt,Avg AMF Damage Dealt,Avg RoBF Damage Dealt,Avg Bleed Damage Dealt," +
            "Avg Damage Absorbed,Avg Physical Damage Received,Avg DD Received,Avg GA Received,Avg AMF Backlash Received," +
            // Training Stats
            trainingHeaders.join(",") + "," +
            // Equip Stats
            equipHeaders.join(",") + "\n";
          
          // Berechne die Training- und Equipment-Werte einmal für alle Gegner
          let trainingValues = "";
          if (trainingStats) {
            // Nehmen wir die Werte des ersten Minions als Referenz
            const firstMinion = Object.values(trainingStats)[0];
            if (firstMinion) {
              trainingValues = trainingHeaders.map(header => {
                const statData = firstMinion[header];
                if (!statData) return "0";
                return statData.base || 0;
              }).join(",");
            } else {
              trainingValues = trainingHeaders.map(() => "0").join(",");
            }
          } else {
            trainingValues = trainingHeaders.map(() => "0").join(",");
          }

          let equipValues = "";
          if (equipStats) {
            // Nehmen wir die Werte des ersten Minions als Referenz
            const firstMinion = Object.values(equipStats)[0];
            if (firstMinion?.equippedItems) {
              equipValues = equipHeaders.map(header => {
                let total = 0;
                firstMinion.equippedItems.forEach(item => {
                  if (item.calculatedEffects?.statModifiers?.[header]) {
                    total += item.calculatedEffects.statModifiers[header];
                  }
                });
                // Konvertiere Prozentwerte in Zahlen
                if (header !== "enemy_hit_penalty") {
                  total = (total * 100).toFixed(1);
                }
                return total;
              }).join(",");
            } else {
              equipValues = equipHeaders.map(() => "0").join(",");
            }
          } else {
            equipValues = equipHeaders.map(() => "0").join(",");
          }
          
          // Füge Daten für jeden Gegner hinzu
          Object.entries(aggStats).forEach(([opponent, variants]) => {
            if (variants[bonusKey]) {
              const stats = variants[bonusKey];
              const bonus = stats.bonusVariant;
              
              // Berechne Durchschnittswerte für Kampf-Statistiken
              const avgXp = (stats.totalXp / stats.count).toFixed(0);
              const avgCash = (stats.totalCash / stats.count).toFixed(0);
              const avgRounds = (stats.totalRounds / stats.count).toFixed(1);
              const avgRemainingHP = (stats.totalRemainingHP / stats.count).toFixed(0);
              const avgHpDrawn = (stats.totalHpDrawn / stats.count).toFixed(0);
              const avgHpRegenerated = (stats.totalHpRegenerated / stats.count).toFixed(0);
              const avgWeaponDamage = (stats.totalWeaponDamageDealt / stats.count).toFixed(0);
              const avgMagicDamage = (stats.totalMagDamageDone / stats.count).toFixed(0);
              const avgAmfDamage = (stats.totalEnemyAmfDamage / stats.count).toFixed(0);
              const avgRoBFDamage = (stats.totalFlameDamageDealt / stats.count).toFixed(0);
              const avgBleedDamage = (stats.totalBleedDamageDealt / stats.count).toFixed(0);
              const avgDamageAbsorbed = (stats.totalDamageAbsorbed / stats.count).toFixed(0);
              const avgPhysDamageReceived = (stats.totalPhysDamageReceived / stats.count).toFixed(0);
              const avgMagDamageReceived = (stats.totalMagDamageReceived / stats.count).toFixed(0);
              const avgGaDamageReceived = (stats.totalGaDamageReceived / stats.count).toFixed(0);
              const avgAmfBacklash = (stats.totalAmfBacklash / stats.count).toFixed(0);
              const avgRobfDamageReceived = (stats.totalRobfDamageReceived / stats.count).toFixed(0);

              // CSV Zeile erstellen
              csvContent += `${opponent},${stats.count},${bonus.challengeBonus},${bonus.clanBonus},${bonus.NUB},${bonus.bonusTime},` +
                `${avgXp},${avgCash},${avgRounds},${avgRemainingHP},${avgHpDrawn},${avgHpRegenerated},` +
                `${avgWeaponDamage},${avgMagicDamage},${avgAmfDamage},${avgRoBFDamage},${avgBleedDamage},` +
                `${avgDamageAbsorbed},${avgPhysDamageReceived},${avgMagDamageReceived},${avgGaDamageReceived},${avgAmfBacklash},` +
                `${avgRobfDamageReceived},${trainingValues}${trainingValues ? "," : ""}${equipValues}\n`;
            }
          });
          
          // CSV Datei herunterladen
          const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
          const link = document.createElement("a");
          const url = URL.createObjectURL(blob);
          link.setAttribute("href", url);
          link.setAttribute("download", `carnageblender_stats_${new Date().toISOString().split('T')[0]}.csv`);
          link.style.visibility = 'hidden';
          document.body.appendChild(link);
          link.click();
          document.body.removeChild(link);
        });
      });
    });
  }

  if (trainingLink) {
    trainingLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentView = "training";
      updateView();
    });
  }

  if (equipLink) {
    equipLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentView = "equip";
      updateView();
    });
  }

  if (lastFightLink) {
    lastFightLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentView = "lastFight";
      updateView();
    });
  }

  if (cycleLink) {
    cycleLink.addEventListener("click", e => {
      e.preventDefault();
      chrome.storage.local.get({ aggStats: {} }, data => {
        const aggStats = data.aggStats;
        const availableBonusKeys = Array.from(new Set(
          Object.values(aggStats).flatMap(opponentVariants => 
            Object.keys(opponentVariants)
          )
        ));
        if (availableBonusKeys.length > 0) {
          const currentIndex = availableBonusKeys.indexOf(window.CBState.currentBonusKey);
          const nextIndex = (currentIndex + 1) % availableBonusKeys.length;
          window.CBState.currentBonusKey = availableBonusKeys[nextIndex];
          updateFightHistoryStats();
        }
      });
    });
  }

  // Füge Event-Listener für cycleStat hinzu
  const cycleStatLink = sidebarFrame.document.getElementById("cycleStat");
  if (cycleStatLink) {
    cycleStatLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentStatIndex = (window.CBState.currentStatIndex + 1) % availableStats.length;
      updateFightHistoryStats();
    });
  }

  // Füge Event-Listener für cycleStatBackwards hinzu
  const cycleStatBackwardsLink = sidebarFrame.document.getElementById("cycleStatBackwards");
  if (cycleStatBackwardsLink) {
    cycleStatBackwardsLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentStatIndex = (window.CBState.currentStatIndex - 1 + availableStats.length) % availableStats.length;
      updateFightHistoryStats();
    });
  }

  // Füge Click-Handler für Opponent-Rows hinzu
  sidebarFrame.document
    .querySelectorAll(".opponent-row")
    .forEach(row => {
      row.addEventListener("click", () => {
        const opp = row.getAttribute("data-opponent");
        window.CBState.currentView = "detail";  // Setze View auf detail
        updateDetailView(opp);
      });
    });

  if (settingsLink) {
    settingsLink.addEventListener("click", e => {
      e.preventDefault();
      window.CBState.currentView = "settings";
      updateView();
    });
  }
};

// Export stats to CSV
const exportStats = () => {
  // Hole die Statistiken aus dem localStorage
  const trainingStatsStr = localStorage.getItem('trainingStats');
  let trainingStats = {};
  if (trainingStatsStr) {
    try {
      trainingStats = JSON.parse(trainingStatsStr);
    } catch (e) {
      console.error('Fehler beim Parsen der Trainingsdaten:', e);
    }
  }

  // Hole die Ausrüstungsstatistiken aus dem chrome.storage
  chrome.storage.local.get(['equipStats'], data => {
    const equipStats = data.equipStats || {};
    
    // Sammle alle verfügbaren Statistiknamen
    const allTrainingStats = new Set();
    const allEquipStats = new Set();
    
    // Sammle Training Stats Namen
    Object.values(trainingStats).forEach(minionStats => {
      Object.keys(minionStats).forEach(stat => allTrainingStats.add(stat));
    });
    
    // Sammle Equipment Stats Namen
    Object.values(equipStats).forEach(minionStats => {
      if (minionStats.equippedItems) {
        minionStats.equippedItems.forEach(item => {
          if (item.calculatedEffects?.statModifiers) {
            Object.keys(item.calculatedEffects.statModifiers).forEach(stat => 
              allEquipStats.add(stat)
            );
          }
        });
      }
    });

    // Erstelle CSV Header
    const csvHeader = ['Minion Name'];
    
    // Training Stats Spalten
    csvHeader.push('Base HP', 'Modified HP', 'HP Change %');
    Array.from(allTrainingStats)
      .filter(stat => stat !== 'Hit Points')
      .sort()
      .forEach(stat => {
        csvHeader.push(`Base ${stat}`, `Modified ${stat}`, `${stat} Change %`);
      });
    
    // Equipment Stats Spalten
    csvHeader.push('Base AC', 'Enchanted AC', 'Total AC', 'Physical DR', 'Magical DR');
    Array.from(allEquipStats).sort().forEach(stat => {
      csvHeader.push(`Equipment ${stat}`);
    });

    // Erstelle CSV Zeilen
    const csvRows = [csvHeader];
    
    // Sammle alle Minion Namen
    const allMinions = new Set([
      ...Object.keys(trainingStats),
      ...Object.keys(equipStats)
    ]);

    // Füge Daten für jeden Minion hinzu
    allMinions.forEach(minionName => {
      const row = [minionName];
      
      // Training Stats
      const minionTraining = trainingStats[minionName] || {};
      
      // HP Werte zuerst
      const hp = minionTraining['Hit Points'] || { base: 0, modified: 0, percentChange: '0.0' };
      row.push(hp.base, hp.modified, hp.percentChange);
      
      // Andere Training Stats
      Array.from(allTrainingStats)
        .filter(stat => stat !== 'Hit Points')
        .sort()
        .forEach(stat => {
          const statData = minionTraining[stat] || { base: 0, modified: 0, percentChange: '0.0' };
          row.push(statData.base, statData.modified, statData.percentChange);
        });
      
      // Equipment Stats
      const minionEquip = equipStats[minionName] || {};
      row.push(
        minionEquip.baseAC || 0,
        minionEquip.enchantmentAC || 0,
        minionEquip.totalAC || 0,
        minionEquip.damageReduction?.physical?.replace('%', '') || 0,
        minionEquip.damageReduction?.magical?.replace('%', '') || 0
      );
      
      // Equipment Stat Modifikatoren
      const statModifiers = {};
      if (minionEquip.equippedItems) {
        minionEquip.equippedItems.forEach(item => {
          if (item.calculatedEffects?.statModifiers) {
            Object.entries(item.calculatedEffects.statModifiers).forEach(([stat, value]) => {
              statModifiers[stat] = (statModifiers[stat] || 0) + value;
            });
          }
        });
      }
      
      Array.from(allEquipStats).sort().forEach(stat => {
        row.push(statModifiers[stat] || 0);
      });
      
      csvRows.push(row);
    });

    // Konvertiere zu CSV String
    const csvContent = csvRows.map(row => 
      row.map(cell => {
        // Wenn die Zelle ein String ist und Kommas oder Anführungszeichen enthält
        if (typeof cell === 'string' && (cell.includes(',') || cell.includes('"'))) {
          // Ersetze " durch "" und umschließe mit Anführungszeichen
          return `"${cell.replace(/"/g, '""')}"`;
        }
        return cell;
      }).join(',')
    ).join('\n');

    // Erstelle Blob und Download
    const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
    const link = document.createElement('a');
    if (link.download !== undefined) {
      const url = URL.createObjectURL(blob);
      link.setAttribute('href', url);
      link.setAttribute('download', 'carnage_blender_stats.csv');
      link.style.visibility = 'hidden';
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    }
  });
};

// Export view functions
window.CBView = {
  updateView,
  updateTrainingStatsDisplay,
  updateEquipStatsDisplay,
  updateLastFightView,
  updateDetailView,
  updateFightHistoryStats,
  addFightHistoryEventListeners,
  updateSettingsView
};

// Initialisiere die Extension
const initializeExtension = () => {
  // Initialisiere CBState falls noch nicht vorhanden
  if (!window.CBState) {
    window.CBState = {
      currentView: "global", // Standard-View
      currentStatIndex: 0,   // XP als Standard-Statistik
      currentBonusKey: null,
      currentMinionFilter: null,
      lastFightData: null,
      windowHeight: 220      // Standard-Fensterhöhe
    };
  }

  // Lade Einstellungen
  window.CBStorage.loadSettings();
  
  // Lade Items-Daten, falls noch nicht geladen
  if (!window.CBState.loadedItems) {
    window.CBStorage.loadItemsData();
  }

  // Lade alle notwendigen Daten
  chrome.storage.local.get({
    aggStats: {},
    lastFightsByOpponent: {},
    equipStats: {}
  }, data => {
    // Speichere die Daten im State
    window.CBState.aggStats = data.aggStats;
    window.CBState.lastFightsByOpponent = data.lastFightsByOpponent;
    window.CBState.equipStats = data.equipStats;

    // Lade Training Stats
    const trainingStatsStr = localStorage.getItem('trainingStats');
    if (trainingStatsStr) {
      try {
        window.CBState.trainingStats = JSON.parse(trainingStatsStr);
      } catch (e) {
        console.error('Fehler beim Parsen der Trainingsdaten:', e);
        window.CBState.trainingStats = {};
      }
    }

    // Initialisiere den currentBonusKey falls noch nicht gesetzt
    if (!window.CBState.currentBonusKey) {
      // Finde den neuesten Bonus-Key mit tatsächlichen Kämpfen
      let newestDate = null;
      let newestBonusKey = null;

      Object.entries(data.aggStats).forEach(([opponent, opponentVariants]) => {
        Object.entries(opponentVariants).forEach(([bonusKey, stats]) => {
          if (stats.count > 0) {
            const lastFight = data.lastFightsByOpponent[opponent]?.[bonusKey];
            if (lastFight) {
              const fightDate = new Date(lastFight.date + ' ' + lastFight.time);
              if (!newestDate || fightDate > newestDate) {
                newestDate = fightDate;
                newestBonusKey = bonusKey;
              }
            }
          }
        });
      });

      window.CBState.currentBonusKey = newestBonusKey || "any|0%|0%|-";
    }

    // Initialisiere die View
    updateView();

    // Wichtig: Füge Event-Handler nach dem Update der View hinzu
    const sidebarFrame = window.CBUtils.getSidebarFrame();
    if (sidebarFrame) {
      addFightHistoryEventListeners(sidebarFrame);
    }
  });
};

// Füge die Initialisierung zum window.CBView Objekt hinzu
window.CBView = {
  ...window.CBView,
  initializeExtension
};

// Führe die Initialisierung aus, sobald das Dokument geladen ist
if (document.readyState === 'complete') {
  initializeExtension();
  updateEquipStatsDisplay();
  updateFightHistoryStats();

} else {
  document.addEventListener('DOMContentLoaded', initializeExtension);
}

